@@ -382,12 +382,12 @@ data_src_cell_toggled(GtkCellRendererToggle * cell, gchar * path, gpointer data)
 	data_src_gui_t * gui = (data_src_gui_t *)data;
 
 	if (gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(gui->list), &iter, path)) {
-		gboolean bool;
+		gboolean value;
 		int type;
 
-		gtk_tree_model_get(GTK_TREE_MODEL(gui->list), &iter, 0, &bool, 1, &type, -1);
+		gtk_tree_model_get(GTK_TREE_MODEL(gui->list), &iter, 0, &value, 1, &type, -1);
 		gtk_list_store_set(GTK_LIST_STORE(gui->list), &iter,
-				   0, !bool && (type != DATA_SRC_CDDB || gui->model->cddb_mask), -1);
+				   0, !value && (type != DATA_SRC_CDDB || gui->model->cddb_mask), -1);
 	}
 }
 
@@ -569,7 +569,7 @@ capitalize_gui_new(capitalize_t * model, GtkWidget * target_vbox) {
 	frame = gtk_frame_new(_("Capitalization"));
         gtk_box_pack_start(GTK_BOX(target_vbox), frame, FALSE, FALSE, 5);
 
-        vbox = gtk_vbox_new(FALSE, 0);
+        vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 
@@ -584,12 +584,12 @@ capitalize_gui_new(capitalize_t * model, GtkWidget * target_vbox) {
 	g_signal_connect(G_OBJECT(gui->check), "toggled",
 			 G_CALLBACK(capitalize_check_toggled), gui);
 
-	gui->combo = gtk_combo_box_new_text();
+	gui->combo = gtk_combo_box_text_new();
 	gtk_table_attach(GTK_TABLE(table), gui->combo, 1, 2, 0, 1,
 			 GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 0);
 
-	gtk_combo_box_append_text(GTK_COMBO_BOX(gui->combo), _("All words"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(gui->combo), _("First word only"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(gui->combo), _("All words"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(gui->combo), _("First word only"));
 
 	gui->check_pre = gtk_check_button_new_with_label(_("Force case: "));
 	gtk_widget_set_name(gui->check_pre, "check_on_notebook");
@@ -738,14 +738,14 @@ file_transform_gui_new(file_transform_t * model, GtkWidget * target_vbox) {
 	frame = gtk_frame_new(_("Regular expression"));
         gtk_box_pack_start(GTK_BOX(target_vbox), frame, FALSE, FALSE, 5);
 
-        vbox = gtk_vbox_new(FALSE, 0);
+        vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 
 	table = gtk_table_new(2, 2, FALSE);
         gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 5);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	label = gtk_label_new(_("Regexp:"));
         gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 5);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 0, 1,
@@ -755,7 +755,7 @@ file_transform_gui_new(file_transform_t * model, GtkWidget * target_vbox) {
 	gtk_table_attach(GTK_TABLE(table), gui->entry_regexp, 1, 2, 0, 1,
 			 GTK_FILL | GTK_EXPAND, GTK_FILL, 5, 5);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	label = gtk_label_new(_("Replace:"));
         gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 5);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 1, 2,
@@ -768,7 +768,7 @@ file_transform_gui_new(file_transform_t * model, GtkWidget * target_vbox) {
 	gtk_entry_set_text(GTK_ENTRY(gui->entry_regexp), model->regexp);
 	gtk_entry_set_text(GTK_ENTRY(gui->entry_replacement), model->replacement);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gui->label_error = gtk_label_new("");
 	gtk_widget_modify_fg(gui->label_error, GTK_STATE_NORMAL, &red);
         gtk_box_pack_start(GTK_BOX(hbox), gui->label_error, FALSE, FALSE, 5);
@@ -778,7 +778,7 @@ file_transform_gui_new(file_transform_t * model, GtkWidget * target_vbox) {
 	frame = gtk_frame_new(_("Predefined transformations"));
         gtk_box_pack_start(GTK_BOX(target_vbox), frame, FALSE, FALSE, 5);
 
-        vbox = gtk_vbox_new(FALSE, 0);
+        vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 
@@ -1556,7 +1556,7 @@ build_type_dialog(build_store_t * build_data) {
 
         dialog = gtk_dialog_new_with_buttons(_("Select build type"),
 					     GTK_WINDOW(browser_window),
-					     GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
+					     GTK_DIALOG_DESTROY_WITH_PARENT,
 					     GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 					     GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
 					     NULL);
@@ -1570,7 +1570,7 @@ build_type_dialog(build_store_t * build_data) {
 	gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
 			  notebook);
 
-        vbox = gtk_vbox_new(FALSE, 5);
+        vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
         gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox, NULL);
 
@@ -1581,7 +1581,7 @@ build_type_dialog(build_store_t * build_data) {
 
  	label = gtk_label_new(_("Follows the directory structure to identify the artists and\n"
  				"records. The files are added on a record basis."));
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 30);
  	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
@@ -1594,7 +1594,7 @@ build_type_dialog(build_store_t * build_data) {
  	label = gtk_label_new(_("Recursive search from the root directory for audio files.\n"
  				"The files are processed independently, so only metadata\n"
  				"and filename transformation are available."));
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 30);
  	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
@@ -1699,7 +1699,7 @@ build_dialog(build_store_t * data) {
 
         dialog = gtk_dialog_new_with_buttons(_("Build/Update store"),
 					     GTK_WINDOW(browser_window),
-					     GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
+					     GTK_DIALOG_DESTROY_WITH_PARENT,
 					     GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 					     GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
 					     NULL);
@@ -1716,7 +1716,7 @@ build_dialog(build_store_t * data) {
 
 	/* General */
 
-        gen_vbox = gtk_vbox_new(FALSE, 0);
+        gen_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(gen_vbox), 5);
 	label = gtk_label_new(_("General"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), gen_vbox, label);
@@ -1730,7 +1730,7 @@ build_dialog(build_store_t * data) {
 	gtk_container_add(GTK_CONTAINER(frame), table);
 
 	label = gtk_label_new(_("Root path:"));
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 5);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 0, 1,
 			 GTK_FILL, GTK_FILL, 0, 5);
@@ -1750,20 +1750,20 @@ build_dialog(build_store_t * data) {
 
 	if (data->type == BUILD_TYPE_STRICT) {
 		label = gtk_label_new(_("Structure:"));
-		hbox = gtk_hbox_new(FALSE, 0);
+		hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 		gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 5);
 		gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 1, 2,
 				 GTK_FILL, GTK_FILL, 0, 0);
 
-		gen_depth_combo = gtk_combo_box_new_text();
-		gtk_combo_box_append_text(GTK_COMBO_BOX(gen_depth_combo),
-					  _("root / record / track"));
-		gtk_combo_box_append_text(GTK_COMBO_BOX(gen_depth_combo),
-					  _("root / artist / record / track"));
-		gtk_combo_box_append_text(GTK_COMBO_BOX(gen_depth_combo),
-					  _("root / artist / artist / record / track"));
-		gtk_combo_box_append_text(GTK_COMBO_BOX(gen_depth_combo),
-					  _("root / artist / artist / artist / record / track"));
+		gen_depth_combo = gtk_combo_box_text_new();
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(gen_depth_combo),
+                                               _("root / record / track"));
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(gen_depth_combo),
+                                               _("root / artist / record / track"));
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(gen_depth_combo),
+                                               _("root / artist / artist / record / track"));
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(gen_depth_combo),
+                                               _("root / artist / artist / artist / record / track"));
 		gtk_combo_box_set_active(GTK_COMBO_BOX(gen_depth_combo), data->artist_dir_depth);
 		gtk_table_attach(GTK_TABLE(table), gen_depth_combo, 1, 3, 1, 2,
 				 GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
@@ -1772,7 +1772,7 @@ build_dialog(build_store_t * data) {
 
 	gen_excl_frame = gtk_frame_new(_("Exclude files matching wildcard"));
         gtk_box_pack_start(GTK_BOX(gen_vbox), gen_excl_frame, FALSE, FALSE, 5);
-        gen_excl_frame_hbox = gtk_hbox_new(FALSE, 0);
+        gen_excl_frame_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(gen_excl_frame_hbox), 5);
 	gtk_container_add(GTK_CONTAINER(gen_excl_frame), gen_excl_frame_hbox);
 
@@ -1797,7 +1797,7 @@ build_dialog(build_store_t * data) {
 
 	gen_incl_frame = gtk_frame_new(_("Include only files matching wildcard"));
         gtk_box_pack_start(GTK_BOX(gen_vbox), gen_incl_frame, FALSE, FALSE, 5);
-        gen_incl_frame_hbox = gtk_hbox_new(FALSE, 0);
+        gen_incl_frame_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(gen_incl_frame_hbox), 5);
 	gtk_container_add(GTK_CONTAINER(gen_incl_frame), gen_incl_frame_hbox);
 
@@ -1841,7 +1841,7 @@ build_dialog(build_store_t * data) {
 
 	/* Artist */
 
-        art_vbox = gtk_vbox_new(FALSE, 0);
+        art_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(art_vbox), 5);
 	label = gtk_label_new(_("Artist"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), art_vbox, label);
@@ -1880,23 +1880,23 @@ build_dialog(build_store_t * data) {
 	frame = gtk_frame_new(_("Sort artists by"));
         gtk_box_pack_start(GTK_BOX(art_vbox), frame, FALSE, FALSE, 5);
 
-        vbox = gtk_vbox_new(FALSE, 0);
+        vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 
-	art_sort_combo = gtk_combo_box_new_text();
+	art_sort_combo = gtk_combo_box_text_new();
         gtk_box_pack_start(GTK_BOX(vbox), art_sort_combo, FALSE, FALSE, 0);
 
-	gtk_combo_box_append_text(GTK_COMBO_BOX(art_sort_combo), _("Artist name"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(art_sort_combo), _("Artist name (lowercase)"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(art_sort_combo), _("Directory name"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(art_sort_combo), _("Directory name (lowercase)"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(art_sort_combo), _("Artist name"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(art_sort_combo), _("Artist name (lowercase)"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(art_sort_combo), _("Directory name"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(art_sort_combo), _("Directory name (lowercase)"));
 	gtk_combo_box_set_active(GTK_COMBO_BOX(art_sort_combo), data->artist_sort_by);
 
 
 	/* Record */
 
-        rec_vbox = gtk_vbox_new(FALSE, 0);
+        rec_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(rec_vbox), 5);
 	label = gtk_label_new(_("Record"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), rec_vbox, label);
@@ -1935,18 +1935,18 @@ build_dialog(build_store_t * data) {
 	frame = gtk_frame_new(_("Sort records by"));
         gtk_box_pack_start(GTK_BOX(rec_vbox), frame, FALSE, FALSE, 5);
 
-        vbox = gtk_vbox_new(FALSE, 0);
+        vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 
-	rec_sort_combo = gtk_combo_box_new_text();
+	rec_sort_combo = gtk_combo_box_text_new();
         gtk_box_pack_start(GTK_BOX(vbox), rec_sort_combo, FALSE, FALSE, 0);
 
-	gtk_combo_box_append_text(GTK_COMBO_BOX(rec_sort_combo), _("Record name"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(rec_sort_combo), _("Record name (lowercase)"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(rec_sort_combo), _("Directory name"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(rec_sort_combo), _("Directory name (lowercase)"));
-	gtk_combo_box_append_text(GTK_COMBO_BOX(rec_sort_combo), _("Year"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(rec_sort_combo), _("Record name"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(rec_sort_combo), _("Record name (lowercase)"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(rec_sort_combo), _("Directory name"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(rec_sort_combo), _("Directory name (lowercase)"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(rec_sort_combo), _("Year"));
 	gtk_combo_box_set_active(GTK_COMBO_BOX(rec_sort_combo), data->record_sort_by);
 
 
@@ -1962,7 +1962,7 @@ build_dialog(build_store_t * data) {
 
 	/* Track */
 
-        trk_vbox = gtk_vbox_new(FALSE, 0);
+        trk_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(trk_vbox), 5);
 	label = gtk_label_new(_("Track"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), trk_vbox, label);
@@ -2016,7 +2016,7 @@ build_dialog(build_store_t * data) {
 
 	/* Sandbox */
 
-        snd_vbox = gtk_vbox_new(FALSE, 0);
+        snd_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(snd_vbox), 5);
 	label = gtk_label_new(_("Sandbox"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), snd_vbox, label);
@@ -2034,7 +2034,7 @@ build_dialog(build_store_t * data) {
         gtk_container_set_border_width(GTK_CONTAINER(table), 5);
 	gtk_container_add(GTK_CONTAINER(frame), table);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	label = gtk_label_new(_("Filename:"));
         gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 5);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 0, 1,
@@ -2247,7 +2247,7 @@ progress_window(build_store_t * data) {
                          G_CALLBACK(prog_window_close), data);
         gtk_container_set_border_width(GTK_CONTAINER(data->prog_window), 5);
 
-        vbox = gtk_vbox_new(FALSE, 0);
+        vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_add(GTK_CONTAINER(data->prog_window), vbox);
 
 	table = gtk_table_new(2, 2, FALSE);
@@ -2255,21 +2255,21 @@ progress_window(build_store_t * data) {
 
 	insert_label_entry(table, _("Processing:"), &data->prog_file_entry, NULL, 0, 1, FALSE);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	label = gtk_label_new(_("Action:"));
         gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, TRUE, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 1, 2,
 			 GTK_FILL, GTK_FILL, 5, 5);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	data->prog_action_label = gtk_label_new("");
         gtk_box_pack_start(GTK_BOX(hbox), data->prog_action_label, FALSE, TRUE, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 1, 2, 1, 2,
 			 GTK_FILL, GTK_FILL, 5, 5);
 
-        gtk_box_pack_start(GTK_BOX(vbox), gtk_hseparator_new(), FALSE, TRUE, 5);
+        gtk_box_pack_start(GTK_BOX(vbox), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), FALSE, TRUE, 5);
 
-	hbuttonbox = gtk_hbutton_box_new();
+	hbuttonbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_end(GTK_BOX(vbox), hbuttonbox, FALSE, TRUE, 0);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(hbuttonbox), GTK_BUTTONBOX_END);
 
