@@ -121,7 +121,7 @@ char destdir[MAXLEN];
 GtkWidget *
 create_notebook_page(GtkWidget * nb, char * title) {
 
-        GtkWidget * vbox = gtk_vbox_new(FALSE, 0);
+        GtkWidget * vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
         gtk_notebook_append_page(GTK_NOTEBOOK(nb), vbox, gtk_label_new(title));
 	return vbox;
@@ -134,7 +134,7 @@ create_frame_on_page(GtkWidget * vbox, char * title) {
 	GtkWidget * vbox1;
 	GtkWidget * frame = gtk_frame_new(title);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 5);
-        vbox1 = gtk_vbox_new(FALSE, 0);
+        vbox1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_add(GTK_CONTAINER(frame), vbox1);
 	return vbox1;
 }
@@ -250,12 +250,12 @@ ripper_destdir_browse_cb(GtkButton * button, gpointer data) {
 GtkWidget *
 create_ripper_deststore_combo(void) {
 
-	GtkWidget * combo = gtk_combo_box_new_text();
+	GtkWidget * combo = gtk_combo_box_text_new();
 	GtkTreeIter iter;
 	int n = 0;
 	int i;
 
-	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("(none)"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("(none)"));
 
 	i = 0;
 	while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(music_store), &iter, NULL, i++)) {
@@ -276,7 +276,7 @@ create_ripper_deststore_combo(void) {
 
                 gtk_tree_model_get(GTK_TREE_MODEL(music_store), &iter,
 				   MS_COL_NAME, &name, -1);
-		gtk_combo_box_append_text(GTK_COMBO_BOX(combo), name);
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), name);
 		++n;
 		g_free(name);
 	}
@@ -334,23 +334,23 @@ get_ripper_deststore_iter(GtkTreeIter * iter_store) {
 GtkWidget *
 create_ripper_format_combo(void) {
 
-	GtkWidget * combo = gtk_combo_box_new_text();
+	GtkWidget * combo = gtk_combo_box_text_new();
 	int n = -1;
 
 #ifdef HAVE_SNDFILE_ENC
-	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "WAV");
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), "WAV");
 	++n;
 #endif /* HAVE_SNDFILE_ENC */
 #ifdef HAVE_FLAC_ENC
-	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "FLAC");
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), "FLAC");
 	++n;
 #endif /* HAVE_FLAC_ENC */
 #ifdef HAVE_VORBISENC
-	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "Ogg Vorbis");
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), "Ogg Vorbis");
 	++n;
 #endif /* HAVE_VORBISENC */
 #ifdef HAVE_LAME
-	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "MP3");
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), "MP3");
 	++n;
 #endif /* HAVE_LAME */
 
@@ -369,7 +369,7 @@ int
 get_ripper_format(void) {
 
 	int file_lib = -1;
-	gchar * text = gtk_combo_box_get_active_text(GTK_COMBO_BOX(ripper_format_combo));
+	gchar * text = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(ripper_format_combo));
 	if (strcmp(text, "WAV") == 0) {
 		file_lib = ENC_SNDFILE_LIB;
 	}
@@ -391,7 +391,7 @@ void
 ripper_bitrate_changed(GtkRange * range, gpointer data) {
 
 	float val = gtk_range_get_value(range);
-	gchar * text = gtk_combo_box_get_active_text(GTK_COMBO_BOX(ripper_format_combo));
+	gchar * text = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(ripper_format_combo));
 	if (strcmp(text, "FLAC") == 0) {
 		int i = (int)val;
 		char str[256];
@@ -429,7 +429,7 @@ ripper_bitrate_changed(GtkRange * range, gpointer data) {
 void
 ripper_format_combo_changed(GtkWidget * widget, gpointer data) {
 
-	gchar * text = gtk_combo_box_get_active_text(GTK_COMBO_BOX(widget));
+	gchar * text = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(widget));
 
 	if (strcmp(text, "WAV") == 0) {
 		gtk_widget_hide(ripper_bitrate_scale);
@@ -652,7 +652,7 @@ cd_ripper_dialog(cdda_drive_t * drive, GtkTreeIter * iter) {
 
         ripper_dialog = gtk_dialog_new_with_buttons(_("Rip CD"),
                                              GTK_WINDOW(browser_window),
-                                             GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
+                                             GTK_DIALOG_DESTROY_WITH_PARENT,
                                              GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
                                              GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
                                              NULL);
@@ -723,7 +723,7 @@ cd_ripper_dialog(cdda_drive_t * drive, GtkTreeIter * iter) {
         gtk_tree_view_append_column(GTK_TREE_VIEW(source_tree), GTK_TREE_VIEW_COLUMN(column));
 
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(hbox), 2);
         gtk_table_attach(GTK_TABLE(table), hbox, 0, 2, 5, 6, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 
@@ -746,7 +746,7 @@ cd_ripper_dialog(cdda_drive_t * drive, GtkTreeIter * iter) {
 	frame = gtk_frame_new(_("Target directory for ripped files"));
 	gtk_box_pack_start(GTK_BOX(vbox_dest1), frame, FALSE, FALSE, 2);
         gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
         gtk_container_add(GTK_CONTAINER(frame), hbox);
 
@@ -760,7 +760,7 @@ cd_ripper_dialog(cdda_drive_t * drive, GtkTreeIter * iter) {
 			 (gpointer)ripper_destdir_entry);
         gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 4);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start(GTK_BOX(vbox_dest1), hbox, FALSE, FALSE, 5);
 
 	gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(_("Add to Music Store")), FALSE, FALSE, 7);
@@ -773,7 +773,7 @@ cd_ripper_dialog(cdda_drive_t * drive, GtkTreeIter * iter) {
         table = gtk_table_new(4, 2, TRUE);
         gtk_box_pack_start(GTK_BOX(vbox_format), table, TRUE, TRUE, 0);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(_("File format:")), FALSE, FALSE, 0);
         gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 4);
 
@@ -781,12 +781,12 @@ cd_ripper_dialog(cdda_drive_t * drive, GtkTreeIter * iter) {
         gtk_table_attach(GTK_TABLE(table), ripper_format_combo, 1, 2, 0, 1,
 			 GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 2);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	ripper_bitrate_label = gtk_label_new(_("Compression level:"));
         gtk_box_pack_start(GTK_BOX(hbox), ripper_bitrate_label, FALSE, FALSE, 0);
         gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 5, 0);
 
-	ripper_bitrate_scale = gtk_hscale_new_with_range(0, 8, 1);
+	ripper_bitrate_scale = gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL, 0, 8, 1);
         g_signal_connect(G_OBJECT(ripper_bitrate_scale), "value-changed",
 			 G_CALLBACK(ripper_bitrate_changed), NULL);
 	gtk_scale_set_draw_value(GTK_SCALE(ripper_bitrate_scale), FALSE);
@@ -836,7 +836,7 @@ cd_ripper_dialog(cdda_drive_t * drive, GtkTreeIter * iter) {
         gtk_box_pack_start(GTK_BOX(vbox_para1), ripper_neverskip_check, FALSE, FALSE, 3);
         g_signal_connect(ripper_neverskip_check, "toggled", G_CALLBACK(ripper_paranoia_toggled), NULL);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_box_pack_start(GTK_BOX(vbox_para1), hbox, FALSE, FALSE, 3);
 
 	ripper_maxretries_label = gtk_label_new(_("Maximum number of retries:"));
@@ -1032,7 +1032,7 @@ ripper_window(void) {
                          G_CALLBACK(ripper_prog_window_state_changed), NULL);
         gtk_container_set_border_width(GTK_CONTAINER(ripper_prog_window), 5);
 
-        vbox = gtk_vbox_new(FALSE, 0);
+        vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_add(GTK_CONTAINER(ripper_prog_window), vbox);
 
         viewport = gtk_viewport_new(NULL, NULL);
@@ -1072,7 +1072,7 @@ ripper_window(void) {
         column = gtk_tree_view_column_new_with_attributes(_("Progress"), cell, "value", 3, NULL);
         gtk_tree_view_append_column(GTK_TREE_VIEW(prog_tree), GTK_TREE_VIEW_COLUMN(column));
 
-        ripper_hbox = gtk_hbox_new(FALSE, 0);
+        ripper_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_box_pack_end(GTK_BOX(vbox), ripper_hbox, FALSE, TRUE, 5);
 
 	ripper_close_when_ready_check = gtk_check_button_new_with_label(_("Close window when complete"));
