@@ -313,7 +313,7 @@ create_query_progress_window(cddb_lookup_t * data) {
 			 G_CALLBACK(abort_cb), data);
         gtk_container_set_border_width(GTK_CONTAINER(data->progress_win), 10);
 	
-	vbox = gtk_vbox_new(FALSE, 0);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add(GTK_CONTAINER(data->progress_win), vbox);
 
 	data->progress_label = gtk_label_new(_("Retrieving matches from server..."));
@@ -323,11 +323,11 @@ create_query_progress_window(cddb_lookup_t * data) {
 	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(data->progbar), _("Connecting to CDDB server..."));
 	gtk_box_pack_start(GTK_BOX(vbox), data->progbar, FALSE, FALSE, 6);
 	
-        hseparator = gtk_hseparator_new ();
+        hseparator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
         gtk_widget_show (hseparator);
         gtk_box_pack_start (GTK_BOX (vbox), hseparator, FALSE, TRUE, 5);
 
-	hbuttonbox = gtk_hbutton_box_new();
+	hbuttonbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_end(GTK_BOX(vbox), hbuttonbox, FALSE, TRUE, 0);
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(hbuttonbox), GTK_BUTTONBOX_END);
 
@@ -908,7 +908,7 @@ cddb_dialog(cddb_lookup_t * data) {
 
         dialog = gtk_dialog_new_with_buttons(NULL,
 					     GTK_WINDOW(browser_window),
-					     GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
+					     GTK_DIALOG_DESTROY_WITH_PARENT,
 					     GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 					     GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
 					     NULL);
@@ -922,19 +922,19 @@ cddb_dialog(cddb_lookup_t * data) {
 	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
 			   table, FALSE, FALSE, 2);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 3);
         label = gtk_label_new(_("Matches:"));
         gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 2);
 
-        data->combo = gtk_combo_box_new_text();
+        data->combo = gtk_combo_box_text_new();
         for (i = 0; i < data->nrecords; i++) {
                 arr_snprintf(text, "%d. %s: %s [%x] ",
                              i + 1,
                              notnull(cddb_disc_get_artist(data->records[i])),
                              notnull(cddb_disc_get_title(data->records[i])),
                              cddb_disc_get_discid(data->records[i]));
-                gtk_combo_box_append_text(GTK_COMBO_BOX(data->combo), text);
+                gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(data->combo), text);
         }
 
         gtk_combo_box_set_active(GTK_COMBO_BOX(data->combo), 0);
@@ -942,7 +942,7 @@ cddb_dialog(cddb_lookup_t * data) {
                  
         gtk_table_attach(GTK_TABLE(table), data->combo, 1, 3, 0, 1, GTK_FILL, GTK_FILL, 5, 3);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 5, 3);
 	label = gtk_label_new(_("Artist:"));
         gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 2);
@@ -951,7 +951,7 @@ cddb_dialog(cddb_lookup_t * data) {
 	gtk_table_attach(GTK_TABLE(table), data->artist_entry, 1, 2, 1, 2,
 			 GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND, 5, 3);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 2, 3, GTK_FILL, GTK_FILL, 5, 3);
 	label = gtk_label_new(_("Title:"));
         gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 2);
@@ -960,7 +960,7 @@ cddb_dialog(cddb_lookup_t * data) {
 	gtk_table_attach(GTK_TABLE(table), data->title_entry, 1, 2, 2, 3,
 			 GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND, 5, 3);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 3, 4, GTK_FILL, GTK_FILL, 5, 3);
 	label = gtk_label_new(_("Year:"));
         gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 2);
@@ -969,7 +969,7 @@ cddb_dialog(cddb_lookup_t * data) {
 	gtk_table_attach(GTK_TABLE(table), data->year_spinner, 1, 2, 3, 4,
 			 GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND, 5, 3);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 4, 5, GTK_FILL, GTK_FILL, 5, 3);
 	label = gtk_label_new(_("Category:"));
         gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 2);
@@ -979,7 +979,7 @@ cddb_dialog(cddb_lookup_t * data) {
         gtk_table_attach(GTK_TABLE(table), data->category_entry, 1, 2, 4, 5,
                          GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND, 5, 3);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 5, 6, GTK_FILL, GTK_FILL, 5, 3);
 	label = gtk_label_new(_("Genre:"));
         gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 2);
@@ -988,7 +988,7 @@ cddb_dialog(cddb_lookup_t * data) {
 	gtk_table_attach(GTK_TABLE(table), data->genre_entry, 1, 2, 5, 6,
 			 GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND, 5, 3);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 6, 7, GTK_FILL, GTK_FILL, 5, 3);
 	label = gtk_label_new(_("Extended data:"));
         gtk_box_pack_end(GTK_BOX(hbox), label, FALSE, FALSE, 2);
