@@ -379,6 +379,7 @@ disk_thread(void * arg) {
 
 						decoder_t * dec = (decoder_t *)fdec->pdec;
 						fileinfo_t fileinfo_sent;
+						memset(&fileinfo_sent, 0, sizeof(fileinfo_t));
 
 						cdda_decoder_reopen(dec, filename);
 						fdec->samples_left = fdec->fileinfo.total_samples;
@@ -421,6 +422,7 @@ disk_thread(void * arg) {
 						goto sleep;
 					} else {
 						fileinfo_t fileinfo_sent;
+						memset(&fileinfo_sent, 0, sizeof(fileinfo_t));
 
 						file_decoder_set_rva(fdec, cue.voladj);
 						info->in_SR_prev = info->in_SR;
@@ -629,10 +631,7 @@ disk_thread(void * arg) {
 		{
 			/* suspend thread, wake up after 100 ms */
 #ifndef HAVE_LIBPTHREAD
-			GTimeVal time;
-			GTimeVal * timeout = &time;
-			g_get_current_time(timeout);
-			g_time_val_add(timeout, 100000);
+			gint64 timeout = g_get_real_time() + 100000;
 #else /* HAVE_LIBPTHREAD */
 			struct timeval now;
 			struct timezone tz;
@@ -1895,6 +1894,7 @@ win32_thread(void * arg) {
 void
 load_default_cl(int * argc, char *** argv) {
 
+	static char cl[MAXLEN];
 	int i = 0;
 	xmlDocPtr doc;
         xmlNodePtr cur;
@@ -1903,13 +1903,19 @@ load_default_cl(int * argc, char *** argv) {
         FILE * f;
         char config_file[MAXLEN];
 	char default_param[MAXLEN];
-	char cl[MAXLEN];
+	char *config_dir;
 
         if (chdir(options.confdir) != 0) {
                 if (errno == ENOENT) {
                         fprintf(stderr, "Creating directory %s\n", options.confdir);
                         /* Try creating .config before .config/aqualung */
-                        mkdir(dirname(options.confdir), S_IRUSR | S_IWUSR | S_IXUSR);
+			config_dir = strdup(options.confdir);
+			if (!config_dir) {
+				perror("strdup failed");
+				exit(1);
+			}
+                        mkdir(dirname(config_dir), S_IRUSR | S_IWUSR | S_IXUSR);
+			free(config_dir);
                         if (mkdir(options.confdir, S_IRUSR | S_IWUSR | S_IXUSR) < 0) {
 				perror("cannot create config directory: mkdir");
 				exit(1);
@@ -2004,7 +2010,7 @@ print_info(void) {
 	fprintf(stderr,	"Aqualung -- Music player for GNU/Linux\n");
 	fprintf(stderr, "Build version: %s\n", AQUALUNG_VERSION);
 	fprintf(stderr,
-		"(C) 2004-2014 Tom Szilagyi <tszilagyi@users.sourceforge.net>\n"
+		"(C) 2004-2014, 2025 Tom Szilagyi\n"
 		"This is free software, and you are welcome to redistribute it\n"
 		"under certain conditions; see the file COPYING for details.\n");
 }
