@@ -29,7 +29,7 @@
 #include "file_decoder.h"
 
 
-#define MAX_AUDIO_FRAME_SIZE 192000 // 1 second of 48khz 32bit audio
+#define MAX_AUDIO_FRAME_SIZE 19200 // 0.1 second of 48khz 32bit audio
 #define RB_LAVC_SIZE (3*MAX_AUDIO_FRAME_SIZE)
 
 
