@@ -26,14 +26,9 @@
 #include <string.h>
 
 
-/* expand this to nothing so there's no error when including MACLib.h */
-/* -- talkin' about cross-platform libraries? */
-#define DLLEXPORT
-
 #include "../undef_ac_pkg.h"
-#include <mac/All.h>
-#include <mac/MACLib.h>
-#include <mac/CharacterHelper.h>
+#include <MAC/All.h>
+#include <MAC/MACLib.h>
 #include "../undef_ac_pkg.h"
 #include <config.h>	/* re-establish undefined autoconf macros */
 
@@ -47,7 +42,6 @@
 
 extern size_t sample_size;
 
-
 #define BLOCKS_PER_READ 2048
 
 
@@ -60,16 +54,16 @@ decode_mac(decoder_t * dec) {
 
 	mac_pdata_t * pd = (mac_pdata_t *)dec->pdata;
 	file_decoder_t * fdec = dec->fdec;
-	IAPEDecompress * pdecompress = (IAPEDecompress *)pd->decompress;
+	APE::IAPEDecompress * pdecompress = (APE::IAPEDecompress *)pd->decompress;
 
-	int act_read = 0;
+	APE::int64 act_read = 0;
 	unsigned long scale = 1 << (pd->bits_per_sample - 1);
 	float fbuf[2 * BLOCKS_PER_READ];
 	int n = 0;
 
 	switch (pd->bits_per_sample) {
 	case 8:
-		char data8[2 * BLOCKS_PER_READ];
+		unsigned char data8[2 * BLOCKS_PER_READ];
 		pdecompress->GetData(data8, BLOCKS_PER_READ, &act_read);
 		if (!act_read) {
 			return 1;
@@ -84,7 +78,7 @@ decode_mac(decoder_t * dec) {
 
 	case 16:
 		short data16[2 * BLOCKS_PER_READ];
-		pdecompress->GetData((char *)data16, BLOCKS_PER_READ, &act_read);
+		pdecompress->GetData((unsigned char *)data16, BLOCKS_PER_READ, &act_read);
 		if (!act_read) {
 			return 1;
 		}
@@ -100,7 +94,7 @@ decode_mac(decoder_t * dec) {
 
 	case 32:
 		int data32[2 * BLOCKS_PER_READ];
-		pdecompress->GetData((char *)data32, BLOCKS_PER_READ, &act_read);
+		pdecompress->GetData((unsigned char *)data32, BLOCKS_PER_READ, &act_read);
 		if (!act_read) {
 			return 1;
 		}
@@ -170,31 +164,34 @@ mac_decoder_open(decoder_t * dec, char * filename) {
 	mac_pdata_t * pd = (mac_pdata_t *)dec->pdata;
 	file_decoder_t * fdec = dec->fdec;
 	metadata_t * meta;
-	IAPEDecompress * pdecompress = (IAPEDecompress *)pd->decompress;
+	APE::IAPEDecompress * pdecompress = (APE::IAPEDecompress *)pd->decompress;
 	const char * comp_level = NULL;
 
 
 	int ret = 0;
-#ifdef __OpenBSD__
-        wchar_t * pUTF16 = GetUTF16FromANSI(filename);
-#else
-        wchar_t * pUTF16 = CAPECharacterHelper::GetUTF16FromANSI(filename);
-#endif
-        pdecompress = CreateIAPEDecompress(pUTF16, &ret);
-        free(pUTF16);
+        int filename_len = strlen(filename);
+        int i;
+        APE::str_utfn * filename_utf16 = new APE::str_utfn [static_cast<size_t>(filename_len) + 1];
+
+        for (i = 0; i < filename_len; i++)
+            filename_utf16[i] = (APE::str_utfn)(APE::str_utf8)filename[i];
+        filename_utf16[i] = 0;
+
+        pdecompress = CreateIAPEDecompress(filename_utf16, &ret, FALSE, FALSE, FALSE);
+        delete [] filename_utf16;
 
         if (!pdecompress || ret != ERROR_SUCCESS) {
                 return DECODER_OPEN_BADLIB;
         }
 
 	pd->decompress = (void *)pdecompress;
-        pd->sample_rate = pdecompress->GetInfo(APE_INFO_SAMPLE_RATE);
-        pd->bits_per_sample = pdecompress->GetInfo(APE_INFO_BITS_PER_SAMPLE);
-        pd->bitrate = pdecompress->GetInfo(APE_DECOMPRESS_AVERAGE_BITRATE);
-        pd->channels = pdecompress->GetInfo(APE_INFO_CHANNELS);
-        pd->length_in_ms = pdecompress->GetInfo(APE_DECOMPRESS_LENGTH_MS);
-        pd->block_align = pdecompress->GetInfo(APE_INFO_BLOCK_ALIGN);
-	pd->compression_level = pdecompress->GetInfo(APE_INFO_COMPRESSION_LEVEL);
+        pd->sample_rate = pdecompress->GetInfo(APE::IAPEDecompress::APE_INFO_SAMPLE_RATE);
+        pd->bits_per_sample = pdecompress->GetInfo(APE::IAPEDecompress::APE_INFO_BITS_PER_SAMPLE);
+        pd->bitrate = pdecompress->GetInfo(APE::IAPEDecompress::APE_DECOMPRESS_AVERAGE_BITRATE);
+        pd->channels = pdecompress->GetInfo(APE::IAPEDecompress::APE_INFO_CHANNELS);
+        pd->length_in_ms = pdecompress->GetInfo(APE::IAPEDecompress::APE_DECOMPRESS_LENGTH_MS);
+        pd->block_align = pdecompress->GetInfo(APE::IAPEDecompress::APE_INFO_BLOCK_ALIGN);
+	pd->compression_level = pdecompress->GetInfo(APE::IAPEDecompress::APE_INFO_COMPRESSION_LEVEL);
 
 	if ((pd->channels != 1) && (pd->channels != 2)) {
 		printf("Sorry, MAC file with %d channels is not supported.\n", pd->channels);
@@ -218,19 +215,19 @@ mac_decoder_open(decoder_t * dec, char * filename) {
 	fdec->file_lib = MAC_LIB;
 
 	switch (pd->compression_level) {
-	case COMPRESSION_LEVEL_FAST:
+	case APE_COMPRESSION_LEVEL_FAST:
 		comp_level = _("Compression: Fast");
 		break;
-	case COMPRESSION_LEVEL_NORMAL:
+	case APE_COMPRESSION_LEVEL_NORMAL:
 		comp_level = _("Compression: Normal");
 		break;
-	case COMPRESSION_LEVEL_HIGH:
+	case APE_COMPRESSION_LEVEL_HIGH:
 		comp_level = _("Compression: High");
 		break;
-	case COMPRESSION_LEVEL_EXTRA_HIGH:
+	case APE_COMPRESSION_LEVEL_EXTRA_HIGH:
 		comp_level = _("Compression: Extra High");
 		break;
-	case COMPRESSION_LEVEL_INSANE:
+	case APE_COMPRESSION_LEVEL_INSANE:
 		comp_level = _("Compression: Insane");
 		break;
 	default:
@@ -255,7 +252,7 @@ void
 mac_decoder_close(decoder_t * dec) {
 
 	mac_pdata_t * pd = (mac_pdata_t *)dec->pdata;
-	IAPEDecompress * pdecompress = (IAPEDecompress *)pd->decompress;
+	APE::IAPEDecompress * pdecompress = (APE::IAPEDecompress *)pd->decompress;
 
 	delete(pdecompress);
 	rb_free(pd->rb);
@@ -294,7 +291,7 @@ mac_decoder_seek(decoder_t * dec, unsigned long long seek_to_pos) {
 	
 	mac_pdata_t * pd = (mac_pdata_t *)dec->pdata;
 	file_decoder_t * fdec = dec->fdec;
-	IAPEDecompress * pdecompress = (IAPEDecompress *)pd->decompress;
+	APE::IAPEDecompress * pdecompress = (APE::IAPEDecompress *)pd->decompress;
 	char flush_dest;
 
 	pdecompress->Seek(seek_to_pos);
