@@ -276,9 +276,13 @@ export_finish(gpointer user_data) {
 
 	export_t * export = (export_t *)user_data;
 
+	GtkAllocation allocation;
+	gtk_widget_get_allocation(export_window, &allocation);
+	GtkAllocation slot_allocation;
+	gtk_widget_get_allocation(export->slot, &slot_allocation);
 	gtk_window_resize(GTK_WINDOW(export_window),
-			  export_window->allocation.width,
-			  export_window->allocation.height - export->slot->allocation.height);
+			  allocation.width,
+			  allocation.height - slot_allocation.height);
 
 	gtk_widget_destroy(export->slot);
 	export->slot = NULL;
@@ -734,26 +738,26 @@ export_browse_cb(GtkButton * button, gpointer data) {
 GtkWidget *
 export_create_format_combo(void) {
 
-	GtkWidget * combo = gtk_combo_box_new_text();
+	GtkWidget * combo = gtk_combo_box_text_new();
 	int n = -1;
 
 #ifdef HAVE_SNDFILE_ENC
-	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "WAV");
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), "WAV");
 	++n;
 #endif /* HAVE_SNDFILE_ENC */
 #ifdef HAVE_FLAC_ENC
-	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "FLAC");
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), "FLAC");
 	++n;
 #endif /* HAVE_FLAC_ENC */
 #ifdef HAVE_VORBISENC
-	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "Ogg Vorbis");
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), "Ogg Vorbis");
 	++n;
 #endif /* HAVE_VORBISENC */
 #ifdef HAVE_LAME
-	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), "MP3");
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), "MP3");
 	++n;
 #endif /* HAVE_LAME */
-	gtk_combo_box_append_text(GTK_COMBO_BOX(combo), _("Copy"));
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Copy"));
 	++n;
 
 	if (n >= options.export_file_format) {
@@ -771,7 +775,7 @@ int
 export_get_format_from_combo(GtkWidget * combo) {
 
 	int file_lib = -1;
-	gchar * text = gtk_combo_box_get_active_text(GTK_COMBO_BOX(combo));
+	gchar * text = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(combo));
 	if (strcmp(text, "WAV") == 0) {
 		file_lib = ENC_SNDFILE_LIB;
 	}
@@ -795,7 +799,7 @@ void
 export_format_combo_changed(GtkWidget * widget, gpointer data) {
 
 	export_t * export = (export_t *)data;
-	gchar * text = gtk_combo_box_get_active_text(GTK_COMBO_BOX(widget));
+	gchar * text = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(widget));
 
 	if (strcmp(text, "WAV") == 0 || strcmp(text, _("Copy")) == 0) {
 		gtk_widget_hide(export->bitrate_scale);
@@ -848,7 +852,7 @@ export_bitrate_changed(GtkRange * range, gpointer data) {
 
 	export_t * export = (export_t *)data;
 	float val = gtk_range_get_value(range);
-	gchar * text = gtk_combo_box_get_active_text(GTK_COMBO_BOX(export->format_combo));
+	gchar * text = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(export->format_combo));
 
 	if (strcmp(text, "FLAC") == 0) {
 		int i = (int)val;
@@ -957,7 +961,7 @@ create_export_window() {
 
         gtk_container_set_border_width(GTK_CONTAINER(export_window), 5);
 
-        vbox = gtk_vbox_new(FALSE, 0);
+        vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_add(GTK_CONTAINER(export_window), vbox);
 
         gtk_widget_show_all(export_window);
@@ -979,7 +983,7 @@ export_progress_window(export_t * export) {
 	export->slot = gtk_table_new(5, 2, FALSE);
         gtk_box_pack_start(GTK_BOX(vbox), export->slot, FALSE, FALSE, 0);
 
-	gtk_table_attach(GTK_TABLE(export->slot), gtk_hseparator_new(), 0, 2, 0, 1,
+	gtk_table_attach(GTK_TABLE(export->slot), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), 0, 2, 0, 1,
 			 GTK_FILL, GTK_FILL, 5, 5);
 
 	insert_label_entry(export->slot, _("Source file:"), &export->prog_file_entry1, NULL, 1, 2, FALSE);
@@ -989,7 +993,7 @@ export_progress_window(export_t * export) {
         g_signal_connect(export->prog_cancel_button, "clicked", G_CALLBACK(export_cancel_event), export);
 	insert_label_progbar_button(export->slot, _("Progress:"), &export->progbar, export->prog_cancel_button, 3, 4);
 
-	gtk_table_attach(GTK_TABLE(export->slot), gtk_hseparator_new(), 0, 2, 4, 5,
+	gtk_table_attach(GTK_TABLE(export->slot), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), 0, 2, 4, 5,
 			 GTK_FILL, GTK_FILL, 5, 5);
 
         gtk_widget_grab_focus(export->prog_cancel_button);
@@ -1109,7 +1113,7 @@ export_start(export_t * export) {
 
         export->dialog = gtk_dialog_new_with_buttons(_("Export files"),
 						     GTK_WINDOW(main_window),
-						     GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR,
+						     GTK_DIALOG_DESTROY_WITH_PARENT,
 						     GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 						     GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
 						     NULL);
@@ -1164,7 +1168,7 @@ export_start(export_t * export) {
         table = gtk_table_new(4, 2, FALSE);
         gtk_container_add(GTK_CONTAINER(frame), table);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(_("File format:")), FALSE, FALSE, 0);
         gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 5);
 
@@ -1174,12 +1178,12 @@ export_start(export_t * export) {
         gtk_table_attach(GTK_TABLE(table), export->format_combo, 1, 2, 0, 1,
 			 GTK_EXPAND | GTK_FILL, GTK_FILL, 5, 5);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	export->bitrate_label = gtk_label_new(_("Compression level:"));
         gtk_box_pack_start(GTK_BOX(hbox), export->bitrate_label, FALSE, FALSE, 0);
         gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 5, 5);
 
-	export->bitrate_scale = gtk_hscale_new_with_range(0, 8, 1);
+	export->bitrate_scale = gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL, 0, 8, 1);
         g_signal_connect(G_OBJECT(export->bitrate_scale), "value-changed",
 			 G_CALLBACK(export_bitrate_changed), export);
 	gtk_scale_set_draw_value(GTK_SCALE(export->bitrate_scale), FALSE);
