@@ -219,6 +219,9 @@ fi_new(void) {
 void
 fi_unload(fi_t * fi) {
 	fi->media_ok = FALSE;
+
+	/* We don't need to destroy these widgets if the window is being
+	   closed; see info_window_close. */
 	if (fi->save_button) {
 		if (GTK_IS_WIDGET(fi->save_button)) gtk_widget_destroy(fi->save_button);
 		fi->save_button = NULL;
@@ -341,7 +344,7 @@ fi_can_close(fi_t * fi) {
 
 
 gint
-dismiss(GtkWidget * widget, gpointer data) {
+info_window_close(GtkWidget * widget, GdkEventAny * event, gpointer data) {
 
 	fi_t * fi = (fi_t *)data;
 
@@ -349,6 +352,11 @@ dismiss(GtkWidget * widget, gpointer data) {
 		return TRUE;
 	}
 
+	/* These widgets will be destroyed along with info_window;
+	   stop fi_unload from trying to delete them too. */
+	fi->save_button = NULL;
+	fi->add_tag_table = NULL;
+
 	unregister_toplevel_window(fi->info_window);
 	gtk_widget_destroy(fi->info_window);
 
@@ -358,20 +366,9 @@ dismiss(GtkWidget * widget, gpointer data) {
 
 
 gint
-info_window_close(GtkWidget * widget, GdkEventAny * event, gpointer data) {
+dismiss(GtkWidget * widget, gpointer data) {
 
-	fi_t * fi = (fi_t *)data;
-
-	if (fi_can_close(fi) != TRUE) {
-		return TRUE;
-	}
-
-	unregister_toplevel_window(fi->info_window);
-	gtk_widget_destroy(fi->info_window);
-	trashlist_free(fi->trash);
-
-	fi_delete(fi);
-	return TRUE;
+	return info_window_close(widget, NULL, data);
 }
 
 
@@ -382,11 +379,11 @@ info_window_key_pressed(GtkWidget * widget, GdkEventKey * kevent, gpointer data)
 	int page;
 
 	switch (kevent->keyval) {
-	case GDK_Escape:
+	case GDK_KEY_Escape:
 		dismiss(NULL, data);
 		return TRUE;
 		break;
-	case GDK_Return:
+	case GDK_KEY_Return:
 		page = (gtk_notebook_get_current_page(GTK_NOTEBOOK(fi->nb)) + 1) % fi->n_pages;
 		gtk_notebook_set_current_page(GTK_NOTEBOOK(fi->nb), page);
 		break;
@@ -407,7 +404,8 @@ fi_set_frame_from_source(fi_t * fi, meta_frame_t * frame) {
 			free(frame->field_val);
 		}
 		if (frame->type == META_FIELD_GENRE) {
-			frame->field_val = gtk_combo_box_get_active_text(GTK_COMBO_BOX(frame->source));
+			frame->field_val = gtk_combo_box_text_get_active_text(
+                           GTK_COMBO_BOX_TEXT(frame->source));
 		} else {
 			frame->field_val = strdup(gtk_entry_get_text(GTK_ENTRY(frame->source)));
 		}
@@ -841,7 +839,7 @@ fi_procframe_label_apic(fi_t * fi, meta_frame_t * frame) {
 	char * pic_caption;
 	char str[MAXLEN];
 	GtkWidget * label_frame;
-	GtkWidget * vbox = gtk_vbox_new(FALSE, 0);
+	GtkWidget * vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	GtkWidget * hbox;
 	GtkWidget * label;
 	GtkWidget * button;
@@ -877,13 +875,13 @@ fi_procframe_label_apic(fi_t * fi, meta_frame_t * frame) {
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
 	arr_snprintf(str, _("MIME type: %s"), frame->field_name);
 	source->mime_label = gtk_label_new(str);
 	gtk_box_pack_start(GTK_BOX(hbox), source->mime_label, FALSE, FALSE, 0);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
 	label = gtk_label_new(_("Picture type:"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
@@ -891,21 +889,21 @@ fi_procframe_label_apic(fi_t * fi, meta_frame_t * frame) {
 	if (meta->writable) {
 		int i = 0;
 		char * type_str;
-		hbox = gtk_hbox_new(FALSE, 0);
+		hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 		gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
-		source->type_combo = gtk_combo_box_new_text();
+		source->type_combo = gtk_combo_box_text_new();
 		while (1) {
 			type_str = meta_id3v2_apic_type_to_string(i);
 			if (type_str == NULL) {
 				break;
 			}
-			gtk_combo_box_append_text(GTK_COMBO_BOX(source->type_combo), type_str);
+			gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(source->type_combo), type_str);
 			++i;
 		}
 		gtk_combo_box_set_active(GTK_COMBO_BOX(source->type_combo), frame->int_val);
 		gtk_box_pack_start(GTK_BOX(hbox), source->type_combo, TRUE, TRUE, 0);
 	} else {
-		hbox = gtk_hbox_new(FALSE, 0);
+		hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 		gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
 		arr_snprintf(str, "%s",
 			     meta_id3v2_apic_type_to_string(frame->int_val));
@@ -913,19 +911,19 @@ fi_procframe_label_apic(fi_t * fi, meta_frame_t * frame) {
 		gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	}
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
 	label = gtk_label_new(_("Description:"));
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 
 	if (meta->writable) {
-		hbox = gtk_hbox_new(FALSE, 0);
+		hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 		gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
 		source->descr_entry = gtk_entry_new();
 		gtk_entry_set_text(GTK_ENTRY(source->descr_entry), frame->field_val);
 		gtk_box_pack_start(GTK_BOX(hbox), source->descr_entry, TRUE, TRUE, 0);
 	} else {
-		hbox = gtk_hbox_new(FALSE, 0);
+		hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 		gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
 		label = gtk_label_new((frame->field_val[0] == '\0') ?
 				      _("(no description)") : frame->field_val);
@@ -933,7 +931,8 @@ fi_procframe_label_apic(fi_t * fi, meta_frame_t * frame) {
 	}
 
 
-	hbox = gtk_hbox_new(TRUE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+        gtk_widget_set_hexpand(hbox, TRUE);
 	gtk_box_pack_end(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
 
 	button = gui_stock_label_button(_("Change"), GTK_STOCK_OPEN);
@@ -965,7 +964,7 @@ fi_procframe_label(fi_t * fi, meta_frame_t * frame) {
 		return fi_procframe_label_apic(fi, frame);
 	} else {
 		char str[MAXLEN];
-		GtkWidget * hbox = gtk_hbox_new(FALSE, 0);
+		GtkWidget * hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 		GtkWidget * label;
 		arr_snprintf(str, "%s:", frame->field_name);
 		label = gtk_label_new(str);
@@ -995,7 +994,7 @@ void
 make_genre_combo(meta_frame_t * frame, GtkWidget ** widget, GtkWidget ** entry) {
 
 	int i;
-	GtkWidget * combo = gtk_combo_box_entry_new_text();
+	GtkWidget * combo = gtk_combo_box_text_new_with_entry();
 	GSList * list = NULL;
 	GSList * _list;
 
@@ -1011,7 +1010,7 @@ make_genre_combo(meta_frame_t * frame, GtkWidget ** widget, GtkWidget ** entry)
 	_list = list;
 	while (_list != NULL) {
 		char * genre = id3v1_genre_str_from_code(GPOINTER_TO_INT(_list->data));
-		gtk_combo_box_append_text(GTK_COMBO_BOX(combo), genre);
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), genre);
 		_list = g_slist_next(_list);
 	}
 	g_slist_free(list);
@@ -1040,7 +1039,7 @@ make_apic_widget(meta_frame_t * frame, GtkWidget ** widget, GtkWidget ** entry)
 
 	GtkWidget * apic_frame = gtk_frame_new(NULL);
 	GtkWidget * image = make_image_from_binary(frame);
-	GtkWidget * vbox = gtk_vbox_new(FALSE, 0);
+	GtkWidget * vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 
 	gtk_frame_set_shadow_type(GTK_FRAME(apic_frame), GTK_SHADOW_NONE);
 	gtk_container_add(GTK_CONTAINER(apic_frame), vbox);
@@ -1169,7 +1168,7 @@ fi_fill_tagcombo(GtkComboBox * combo, int addable_tags) {
 		return;
 
 	for (i = 0; i < 100; i++) {
-		gtk_combo_box_remove_text(combo, 0);
+		gtk_combo_box_text_remove(GTK_COMBO_BOX_TEXT(combo), 0);
 	}
 
 	if (addable_tags == 0) {
@@ -1181,7 +1180,7 @@ fi_fill_tagcombo(GtkComboBox * combo, int addable_tags) {
 
 	while (tag <= META_TAG_MAX) {
 		if (addable_tags & tag) {
-			gtk_combo_box_append_text(combo, meta_get_tagname(tag));
+			gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), meta_get_tagname(tag));
 		}
 		tag <<= 1;
 	}
@@ -1217,7 +1216,7 @@ fi_fill_combo_foreach(gpointer data, gpointer user_data) {
 	if (!meta_get_fieldname(field, &str)) {
 		fprintf(stderr, "fi_fill_combo_foreach: programmer error\n");
 	}
-	gtk_combo_box_append_text(combo, str);
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), str);
 }
 
 void
@@ -1226,7 +1225,7 @@ fi_fill_combo(GtkComboBox * combo, GSList * slist) {
 	int i;
 	GSList * sorted_list = g_slist_copy(slist);
 	for (i = 0; i < 100; i++) {
-		gtk_combo_box_remove_text(combo, 0);
+		gtk_combo_box_text_remove(GTK_COMBO_BOX_TEXT(combo), 0);
 	}
 	sorted_list = g_slist_sort(sorted_list, fi_fill_combo_cmp);
 	g_slist_foreach(sorted_list, fi_fill_combo_foreach, combo);
@@ -1323,7 +1322,7 @@ fi_add_button_pressed(GtkWidget * widget, gpointer data) {
 	char * str;
 
 	/* Create new frame */
-	char * combo_entry = gtk_combo_box_get_active_text(GTK_COMBO_BOX(combo));
+	char * combo_entry = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(combo));
 	if (combo_entry == NULL) {
 		return;
 	}
@@ -1382,7 +1381,7 @@ fi_addtag_button_pressed(GtkWidget * widget, gpointer data) {
 	metadata_t * meta = fi->meta;
 	meta_frame_t * frame;
 	int tag;
-	char * combo_entry = gtk_combo_box_get_active_text(GTK_COMBO_BOX(fi->combo));
+	char * combo_entry = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(fi->combo));
 	if (combo_entry == NULL) {
 		return;
 	}
@@ -1423,7 +1422,7 @@ fi_procframe_ins_modinfo(fi_t * fi, meta_frame_t * frame) {
 
 	int page = lookup_page(fi, frame->tag);
 	GtkWidget * table = fi->pageidx[page].table;
-	GtkWidget * vbox = gtk_vbox_new(FALSE, 0);
+	GtkWidget * vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 
 	module_info_fill_page(fi, frame, vbox);
 	gtk_table_attach(GTK_TABLE(table), vbox, 0, 1, 0, 1,
@@ -1590,13 +1589,13 @@ void
 fi_procframe_add_tag_page(fi_t * fi, meta_frame_t * frame) {
 
 	metadata_t * meta = fi->meta;
-	GtkWidget * vbox = gtk_vbox_new(FALSE, 4);
-	GtkWidget * vbox_padding = gtk_vbox_new(FALSE, 0);
+	GtkWidget * vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
+	GtkWidget * vbox_padding = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	GtkWidget * scrwin = gtk_scrolled_window_new(NULL, NULL);
 	GtkWidget * table = gtk_table_new(0, fi_tabwidth(fi, meta), FALSE);
 	GtkWidget * label = gtk_label_new(meta_get_tagname(frame->tag));
-	GtkWidget * hbox = gtk_hbox_new(FALSE, 0);
-	GtkWidget * combo = gtk_combo_box_new_text();
+	GtkWidget * hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+	GtkWidget * combo = gtk_combo_box_text_new();
 	GtkWidget * addbtn, * delbtn;
 	GSList * slist = meta_get_possible_fields(frame->tag);
 
@@ -1727,7 +1726,7 @@ fi_procmeta(metadata_t * meta, void * data) {
 		gtk_table_attach(GTK_TABLE(fi->add_tag_table), gtk_label_new(_("tag:")),
 				 1, 2, 0, 1, GTK_FILL, GTK_FILL, 3, 0);
 
-		fi->combo = gtk_combo_box_new_text();
+		fi->combo = gtk_combo_box_text_new();
 		fi_fill_tagcombo(GTK_COMBO_BOX(fi->combo), fi->addable_tags);
 		gtk_table_attach(GTK_TABLE(fi->add_tag_table), fi->combo,
 				 2, 3, 0, 1, GTK_FILL, GTK_FILL, 3, 0);
@@ -1763,7 +1762,7 @@ fi_cover_press_button_cb (GtkWidget *widget, GdkEventButton *event, gpointer dat
 
 void
 fi_add_file_table_row(char * caption, GtkWidget ** entry, GtkWidget * table, int row) {
-	GtkWidget * hbox = gtk_hbox_new(FALSE, 0);
+	GtkWidget * hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	GtkWidget * label = gtk_label_new(caption);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, row, row+1, GTK_FILL, GTK_FILL, 5, 3);
@@ -2028,10 +2027,10 @@ show_file_info(GtkTreeModel * model, GtkTreeIter iter_track,
 			 G_CALLBACK(info_window_key_pressed), (gpointer)fi);
 	gtk_container_set_border_width(GTK_CONTAINER(fi->info_window), 5);
 
-	vbox = gtk_vbox_new(FALSE, 0);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add(GTK_CONTAINER(fi->info_window), vbox);
 
-	hbox_t = gtk_hbox_new(FALSE, 0);
+	hbox_t = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox_t, FALSE, FALSE, 5);
 
 	table = gtk_table_new(2, 2, FALSE);
@@ -2048,7 +2047,7 @@ show_file_info(GtkTreeModel * model, GtkTreeIter iter_track,
         gtk_container_add (GTK_CONTAINER (fi->event_box), fi->cover_image_area);
         g_signal_connect(G_OBJECT(fi->event_box), "button_press_event",
                          G_CALLBACK(fi_cover_press_button_cb), (gpointer)fi);
-	fi->hbox = gtk_hbox_new(FALSE, 0);
+	fi->hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_end(GTK_BOX(vbox), fi->hbox, FALSE, FALSE, 5);
 
 	fi->nb = gtk_notebook_new();
@@ -2056,7 +2055,7 @@ show_file_info(GtkTreeModel * model, GtkTreeIter iter_track,
 
 	/* Audio data notebook page */
 
-	vbox_file = gtk_vbox_new(FALSE, 4);
+	vbox_file = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
 	table_file = gtk_table_new(6, 2, FALSE);
 	gtk_box_pack_start(GTK_BOX(vbox_file), table_file, TRUE, TRUE, 10);
 	label_file = gtk_label_new(_("Audio data"));
@@ -2221,11 +2220,11 @@ module_info_fill_page(fi_t * fi, meta_frame_t * frame, GtkWidget * vbox) {
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 
-        hbox2 = gtk_hbox_new (FALSE, 0);
+        hbox2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_widget_show (hbox2);
         gtk_box_pack_start (GTK_BOX (vbox), hbox2, TRUE, TRUE, 0);
 
-        vbox2 = gtk_vbox_new (FALSE, 0);
+        vbox2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_widget_show (vbox2);
         gtk_box_pack_start (GTK_BOX (hbox2), vbox2, FALSE, FALSE, 0);
 
@@ -2296,11 +2295,11 @@ module_info_fill_page(fi_t * fi, meta_frame_t * frame, GtkWidget * vbox) {
         arr_snprintf(temp, "%d", mdi->samples);
         gtk_label_set_text (GTK_LABEL(mod_samples_label), temp);
 
-        vseparator = gtk_vseparator_new ();
+        vseparator = gtk_separator_new(GTK_ORIENTATION_VERTICAL);
         gtk_widget_show (vseparator);
         gtk_box_pack_start (GTK_BOX (hbox2), vseparator, FALSE, FALSE, 4);
 
-        vbox3 = gtk_vbox_new (FALSE, 0);
+        vbox3 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_widget_show (vbox3);
         gtk_box_pack_start (GTK_BOX (hbox2), vbox3, TRUE, TRUE, 0);
 
@@ -2346,4 +2345,3 @@ module_info_fill_page(fi_t * fi, meta_frame_t * frame, GtkWidget * vbox) {
 
 
 // vim: shiftwidth=8:tabstop=8:softtabstop=8 :
-
