@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: httpc.c 1245 2012-02-04 10:33:30Z assworth $
+    $Id$
 */
 
 #include <config.h>
@@ -303,19 +303,18 @@ strip_whitespace(char * str) {
 }
 
 int
-parse_field(char * line, char * name, char * value) {
+parse_field(char * line, char * name, size_t name_size, char * value, size_t value_size) {
 	
 	if (line[0] == ' ' || line[0] == '\t') {
 		name[0] = '\0';
-		strcpy(value, strip_whitespace(line));
+		g_strlcpy(value, strip_whitespace(line), value_size);
 	} else {
 		char * c = strstr(line, ":");
 		if (c == NULL)
 			return -1;
-		strncpy(name, line, c-line);
-		name[c-line] = '\0';
-		strncpy(value, c+1, strlen(c)-1);
-		value[strlen(c)-1] = '\0';
+		*c = '\0';
+		g_strlcpy(name, line, name_size);
+		g_strlcpy(value, c + 1, value_size);
 		strip_whitespace(name);
 		strip_whitespace(value);
 	}
@@ -328,8 +327,8 @@ check_http_response(char * line, char * resp) {
 	char http10[16];
 	char http11[16];
 
-	snprintf(http10, 15, "HTTP/1.0 %s", resp);
-	snprintf(http11, 15, "HTTP/1.1 %s", resp);
+	arr_snprintf(http10, "HTTP/1.0 %s", resp);
+	arr_snprintf(http11, "HTTP/1.1 %s", resp);
 
 	return (strstr(line, http10) != NULL) || (strstr(line, http11) != NULL);
 }
@@ -366,14 +365,16 @@ parse_http_headers(http_session_t * session) {
 		if (line[0] == '\0')
 			break;
 		
-		if (parse_field(line, new_name, new_value) == -1)
+		if (parse_field(line, new_name, CHAR_ARRAY_SIZE(new_name),
+				new_value, CHAR_ARRAY_SIZE(new_value)) == -1)
 			return -3;
 		
 		if (new_name[0] == '\0') {
-			snprintf(value, sizeof(value), "%s %s", value, new_value);
+			arr_strlcat(value, " ");
+			arr_strlcat(value, new_value);
 		} else {
-			strcpy(name, new_name);
-			strcpy(value, new_value);
+			arr_strlcpy(name, new_name);
+			arr_strlcpy(value, new_value);
 		}
 		
 		if (strcasecmp(name, "location") == 0) {
@@ -452,7 +453,7 @@ make_http_request_text(char * host, int port, char * path,
 	char extra_header[1024];
 	
 	if (start_byte != 0) {
-		snprintf(extra_header, sizeof(extra_header), "Range: bytes=%lld-\r\n", start_byte);
+		arr_snprintf(extra_header, "Range: bytes=%lld-\r\n", start_byte);
 	} else {
 		extra_header[0] = '\0';
 	}
@@ -595,22 +596,20 @@ httpc_init(http_session_t * session, file_decoder_t * fdec,
 	
 	if ((p = strstr(URL, ":")) != NULL) {
 		unsigned int l = p - URL;
-		if (l > sizeof(host)) {
+		if (l + 1 > sizeof(host)) {
 			return HTTPC_URL_ERROR;
 		}
-		strncpy(host, URL, l);
-		host[l] = '\0';
+		g_strlcpy(host, URL, l + 1);
 		URL += l+1;
 		if ((p = strstr(URL, "/")) != NULL) {
 			unsigned int m = p - URL;
-			if (m > sizeof(port_str)) {
+			if (m + 1 > sizeof(port_str)) {
 				return HTTPC_URL_ERROR;
 			}
-			strncpy(port_str, URL, m);
-			port_str[m] = '\0';
+			g_strlcpy(port_str, URL, m + 1);
 			URL += m;
 		} else {
-			strncpy(port_str, URL, sizeof(port_str));
+			arr_strlcpy(port_str, URL);
 			URL = "/";
 		}
 		if (sscanf(port_str, "%d", &port) != 1) {
@@ -619,15 +618,14 @@ httpc_init(http_session_t * session, file_decoder_t * fdec,
 	} else {
 		if ((p = strstr(URL, "/")) != NULL) {
 			unsigned int l = p - URL;
-			if (l > sizeof(host)) {
+			if (l + 1 > sizeof(host)) {
 				return HTTPC_URL_ERROR;
 			}
-			strncpy(host, URL, l);
-			host[l] = '\0';
+			g_strlcpy(host, URL, l + 1);
 			URL += l;
 			port = 80;      
 		} else {
-			strncpy(host, URL, sizeof(host));
+			arr_strlcpy(host, URL);
 			port = 80;
 			URL = "/";
 		}
