@@ -311,7 +311,7 @@ upload_download_songs_cb(GtkButton * button, gpointer user_data) {
 int
 mkdir_key_press (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
-        if (event->keyval == GDK_Return) {
+        if (event->keyval == GDK_KEY_Return) {
                 gtk_dialog_response(GTK_DIALOG (mkdir_dialog), GTK_RESPONSE_OK);
         }
         return FALSE;
@@ -365,7 +365,7 @@ aifp_create_directory_cb (GtkButton *button, gpointer user_data) {
 gint
 rename_key_press (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
-        if (event->keyval == GDK_Return) {
+        if (event->keyval == GDK_KEY_Return) {
                 gtk_dialog_response(GTK_DIALOG (rename_dialog), GTK_RESPONSE_OK);
         }
         return FALSE;
@@ -767,21 +767,21 @@ aifp_window_key_pressed(GtkWidget * widget, GdkEventKey * kevent) {
         if (!transfer_active) {
 
                 switch (kevent->keyval) {
-                        case GDK_Escape:
+                        case GDK_KEY_Escape:
                                 aifp_window_close (NULL, NULL);
                                 return TRUE;
-                        case GDK_c:
+                        case GDK_KEY_c:
                                 if (transfer_mode == UPLOAD_MODE) {
                                         aifp_create_directory_cb (NULL, NULL);
                                         return TRUE;
                                 } else {
                                         break;
                                 }
-                        case GDK_r:
+                        case GDK_KEY_r:
                                 aifp_rename_item_cb (NULL, NULL);
                                 return TRUE;
-                        case GDK_Delete:
-                        case GDK_KP_Delete:
+                        case GDK_KEY_Delete:
+                        case GDK_KEY_KP_Delete:
                                 aifp_remove_item_cb (NULL, NULL);
                                 return TRUE;
                 }
@@ -824,7 +824,7 @@ gchar *npath;
 
 
 void
-directory_chooser(char * title, GtkWidget * parent, char * directory) {
+directory_chooser(char * title, GtkWidget * parent, char * directory, size_t directory_len) {
 
         GtkWidget * dialog;
 	const gchar * selected_directory;
@@ -855,7 +855,7 @@ directory_chooser(char * title, GtkWidget * parent, char * directory) {
 			gtk_widget_destroy(dialog);
 		}
 
-                arr_strlcpy(directory, selected_directory);
+                g_strlcpy(directory, selected_directory, directory_len);
 		g_free(utf8);
         }
 
@@ -865,7 +865,7 @@ directory_chooser(char * title, GtkWidget * parent, char * directory) {
 
 void
 local_path_selected_cb(GtkButton * button, gpointer data) {
-	directory_chooser(_("Please select a local path."), aifp_window, dest_dir);
+	directory_chooser(_("Please select a local path."), aifp_window, dest_dir, sizeof dest_dir);
         gtk_entry_set_text(GTK_ENTRY(local_path_entry), dest_dir);
 }
 
@@ -959,11 +959,11 @@ aifp_transfer_files(gint mode) {
         gtk_container_set_border_width(GTK_CONTAINER(aifp_window), 5);
         gtk_window_set_default_size(GTK_WINDOW(aifp_window), options.ifpmanager_size_x, options.ifpmanager_size_y);
 
-        vbox1 = gtk_vbox_new (FALSE, 0);
+        vbox1 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_widget_show (vbox1);
         gtk_container_add (GTK_CONTAINER (aifp_window), vbox1);
 
-        vbox2 = gtk_vbox_new (FALSE, 0);
+        vbox2 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_widget_show (vbox2);
         gtk_box_pack_start (GTK_BOX (vbox1), vbox2, TRUE, TRUE, 0);
 
@@ -981,7 +981,7 @@ aifp_transfer_files(gint mode) {
 
         if (transfer_mode == UPLOAD_MODE) {
 
-                hbox1 = gtk_hbox_new (FALSE, 0);
+                hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
                 gtk_widget_show (hbox1);
                 gtk_container_add (GTK_CONTAINER (alignment), hbox1);
 
@@ -1015,11 +1015,11 @@ aifp_transfer_files(gint mode) {
                 gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
         }
 
-        vbox3 = gtk_vbox_new (FALSE, 0);
+        vbox3 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_widget_show (vbox3);
         gtk_container_add (GTK_CONTAINER (alignment), vbox3);
 
-        hbox1 = gtk_hbox_new (FALSE, 0);
+        hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_widget_show (hbox1);
         gtk_box_pack_start (GTK_BOX (vbox3), hbox1, TRUE, TRUE, 2);
 
@@ -1034,7 +1034,7 @@ aifp_transfer_files(gint mode) {
         gtk_misc_set_alignment (GTK_MISC (label_model), 0, 0.5);
         gtk_misc_set_padding (GTK_MISC (label_model), 5, 0);
 
-        hbox1 = gtk_hbox_new (FALSE, 0);
+        hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_widget_show (hbox1);
         gtk_box_pack_start (GTK_BOX (vbox3), hbox1, TRUE, TRUE, 2);
 
@@ -1066,7 +1066,7 @@ aifp_transfer_files(gint mode) {
         gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
         gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
 
-        hbox1 = gtk_hbox_new (FALSE, 0);
+        hbox1 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_widget_show (hbox1);
         gtk_container_add (GTK_CONTAINER (alignment), hbox1);
 
@@ -1108,11 +1108,11 @@ aifp_transfer_files(gint mode) {
         gtk_tree_view_append_column(GTK_TREE_VIEW(list), column);
         gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
 
-        vseparator = gtk_vseparator_new ();
+        vseparator = gtk_separator_new(GTK_ORIENTATION_VERTICAL);
         gtk_widget_show (vseparator);
         gtk_box_pack_start (GTK_BOX (hbox1), vseparator, FALSE, TRUE, 2);
 
-        vbox4 = gtk_vbox_new (FALSE, 0);
+        vbox4 = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_widget_show (vbox4);
         gtk_box_pack_start (GTK_BOX (hbox1), vbox4, FALSE, FALSE, 0);
 
@@ -1176,7 +1176,7 @@ aifp_transfer_files(gint mode) {
                 gtk_container_add (GTK_CONTAINER (frame), alignment);
                 gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
 
-                hbox2 = gtk_hbox_new(FALSE, FALSE);
+                hbox2 = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
                 gtk_container_add (GTK_CONTAINER (alignment), hbox2);
                 gtk_widget_show (hbox2);
 
@@ -1270,11 +1270,11 @@ aifp_transfer_files(gint mode) {
         gtk_widget_show(aifp_close_when_ready_check);
         gtk_box_pack_start(GTK_BOX(vbox2), aifp_close_when_ready_check, FALSE, TRUE, 0);
 
-        hseparator = gtk_hseparator_new ();
+        hseparator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
         gtk_widget_show (hseparator);
         gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 3);
 
-        hbuttonbox = gtk_hbutton_box_new ();
+        hbuttonbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
         gtk_widget_show (hbuttonbox);
         gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, TRUE, 0);
         gtk_container_set_border_width (GTK_CONTAINER (hbuttonbox), 5);
