@@ -54,9 +54,6 @@ extern GtkWidget * musicstore_toggle;
 
 extern GtkListStore * ms_pathlist_store;
 
-extern PangoFontDescription *fd_browser;
-extern PangoFontDescription *fd_statusbar;
-
 GtkWidget * browser_window;
 
 int music_store_changed = 0;
@@ -99,9 +96,9 @@ gint
 browser_window_key_pressed(GtkWidget * widget, GdkEventKey * event) {
 
 	switch (event->keyval) {
-	case GDK_q:
-	case GDK_Q:
-	case GDK_Escape:
+	case GDK_KEY_q:
+	case GDK_KEY_Q:
+	case GDK_KEY_Escape:
 		browser_window_close(NULL, NULL, NULL);
 		return TRUE;
 	}
@@ -208,8 +205,8 @@ music_tree_event_cb(GtkWidget * widget, GdkEvent * event, gpointer user_data) {
 		GdkEventKey * kevent = (GdkEventKey *)event;
 
 		switch (kevent->keyval) {
-		case GDK_KP_Enter:
-		case GDK_Return:
+		case GDK_KEY_KP_Enter:
+		case GDK_KEY_Return:
 			if (gtk_tree_selection_get_selected(music_select, &model, &iter)) {
 
 				GtkTreePath * path = gtk_tree_model_get_path(model, &iter);
@@ -222,12 +219,12 @@ music_tree_event_cb(GtkWidget * widget, GdkEvent * event, gpointer user_data) {
 				gtk_tree_path_free(path);
 			}
 			return TRUE;
-		case GDK_w:
-		case GDK_W:
+		case GDK_KEY_w:
+		case GDK_KEY_W:
 			toolbar__collapse_cb(NULL);
 			return TRUE;
-		case GDK_f:
-		case GDK_F:
+		case GDK_KEY_f:
+		case GDK_KEY_F:
 			toolbar__search_cb(NULL);
 			return TRUE;
 		}
@@ -491,15 +488,6 @@ music_tree_expand_stores(void) {
 	}
 }
 
-void
-music_browser_set_font(int cond) {
-
-        if (cond) {
-		gtk_widget_modify_font(music_tree, fd_browser);
-		gtk_widget_modify_font(statusbar_ms, fd_statusbar);
-	}
-}
-
 void
 create_music_browser(void) {
 
@@ -535,12 +523,12 @@ create_music_browser(void) {
 	gtk_container_set_border_width(GTK_CONTAINER(browser_window), 2);
         gtk_widget_set_size_request(browser_window, 200, 300);
 
-	vbox = gtk_vbox_new(FALSE, 0);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_container_add(GTK_CONTAINER(browser_window), vbox);
 
         if (options.enable_mstore_toolbar) {
 
-                hbox = gtk_hbox_new(FALSE, 0);
+                hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
                 gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 3);
 
                 toolbar_search_button = gui_stock_label_button((gchar *)-1, GTK_STOCK_FIND);
@@ -583,7 +571,7 @@ create_music_browser(void) {
 
 
 	if (!options.hide_comment_pane) {
-		browser_paned = gtk_vpaned_new();
+		browser_paned = gtk_paned_new(GTK_ORIENTATION_VERTICAL);
 		gtk_box_pack_start(GTK_BOX(vbox), browser_paned, TRUE, TRUE, 0);
 	}
 
@@ -751,7 +739,7 @@ create_music_browser(void) {
 		g_signal_connect(G_OBJECT(statusbar_viewport), "motion_notify_event",
 				 G_CALLBACK(scroll_motion_notify), (gpointer)statusbar_scrolledwin);
 
-		statusbar_hbox = gtk_hbox_new(FALSE, 0);
+		statusbar_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 		gtk_container_set_border_width(GTK_CONTAINER(statusbar_hbox), 1);
 		gtk_container_add(GTK_CONTAINER(statusbar_viewport), statusbar_hbox);
 
@@ -759,8 +747,6 @@ create_music_browser(void) {
 		gtk_widget_set_name(statusbar_ms, "label_info");
 		gtk_box_pack_end(GTK_BOX(statusbar_hbox), statusbar_ms, FALSE, FALSE, 0);
 	}
-
-	music_browser_set_font(options.override_skin_settings);
 }
 
 
