@@ -48,9 +48,6 @@ typedef struct {
 	char ripdir[MAXLEN];
 	char storedir[MAXLEN];
 
-	/* directory of skin in use */
-	char skin[MAXLEN];
-
 	/* Misc - not accessible from the Settings dialog */
 	float vol;
 	float bal;
@@ -107,6 +104,7 @@ typedef struct {
 	char title_format[MAXLEN];
 	char default_param[MAXLEN];
 	int enable_tooltips;
+   	int dark_theme;
    	int disable_buttons_relief;
 	int combine_play_pause;
 	int combine_play_pause_shadow;
@@ -213,19 +211,6 @@ typedef struct {
 	char inet_noproxy_domains[MAXLEN];
 	int inet_timeout;
 
-	/* Appearance */
-	int disable_skin_support_settings;
-	int override_skin_settings;
-	char playlist_font[MAX_FONTNAME_LEN];
-	char browser_font[MAX_FONTNAME_LEN];
-	char bigtimer_font[MAX_FONTNAME_LEN];
-	char smalltimer_font[MAX_FONTNAME_LEN];
-	char songtitle_font[MAX_FONTNAME_LEN];
-	char songinfo_font[MAX_FONTNAME_LEN];
-	char statusbar_font[MAX_FONTNAME_LEN];
-	char song_color[MAX_COLORNAME_LEN];
-	char activesong_color[MAX_COLORNAME_LEN];
-
 	/* Lua */
 	char ext_title_format_file[MAXLEN];
 	int use_ext_title_format;
