@@ -338,9 +338,9 @@ gint
 fxbuilder_key_pressed(GtkWidget * widget, GdkEventKey * event, gpointer * data) {
 
         switch (event->keyval) {
-	case GDK_q:
-	case GDK_Q:
-	case GDK_Escape:
+	case GDK_KEY_q:
+	case GDK_KEY_Q:
+	case GDK_KEY_Escape:
 		fxbuilder_close(NULL, NULL, NULL);
 		return TRUE;
 	};
@@ -628,7 +628,7 @@ update_plugin_outputs(gpointer data) {
 
 			while (plugin_lock)
 				;
-			instance->adjustments[k]->value = instance->knobs[k];
+			gtk_adjustment_set_value(instance->adjustments[k], instance->knobs[k]);
 		}
 	}
 
@@ -677,8 +677,8 @@ plugin_window_key_pressed(GtkWidget * widget, GdkEventKey * event, gpointer * da
 	plugin_instance * instance = (plugin_instance *) data;
 
         switch (event->keyval) {
-        case GDK_Shift_L:
-        case GDK_Shift_R:
+        case GDK_KEY_Shift_L:
+        case GDK_KEY_Shift_R:
                 instance->shift_pressed = 1;
                 break;
         }
@@ -693,8 +693,8 @@ plugin_window_key_released(GtkWidget * widget, GdkEventKey * event, gpointer * d
 	plugin_instance * instance = (plugin_instance *) data;
 
         switch (event->keyval) {
-        case GDK_Shift_L:
-        case GDK_Shift_R:
+        case GDK_KEY_Shift_L:
+        case GDK_KEY_Shift_R:
                 instance->shift_pressed = 0;
                 break;
         }
@@ -727,7 +727,7 @@ plugin_scale_btn_pressed(GtkWidget * widget, GdkEventButton * event, gpointer *
 		return FALSE;
 
 	adj = gtk_range_get_adjustment(GTK_RANGE(widget));
-	adj->value = btnpdata->start;
+	gtk_adjustment_set_value(adj, btnpdata->start);
 	gtk_adjustment_value_changed(adj);
 
         return TRUE;
@@ -766,7 +766,7 @@ build_plugin_window(plugin_instance * instance) {
 	GtkWidget * inner_vbox;
 	GtkWidget * table = NULL;
 	GtkWidget * hseparator;
-	GtkObject * adjustment;
+	GObject * adjustment;
 	GtkWidget * combo;
 
 	optdata_t * optdata;
@@ -792,18 +792,18 @@ build_plugin_window(plugin_instance * instance) {
 			      GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
         gtk_container_set_border_width(GTK_CONTAINER(instance->window), 5);
 
-	vbox = gtk_vbox_new(FALSE, 3);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 3);
 	gtk_container_add(GTK_CONTAINER(instance->window), vbox);
 
-	upper_hbox = gtk_hbox_new(FALSE, 0);
+	upper_hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), upper_hbox, FALSE, TRUE, 2);
 
-	upper_vbox = gtk_vbox_new(FALSE, 0);
+	upper_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_box_pack_start(GTK_BOX(upper_hbox), upper_vbox, FALSE, FALSE, 2);
 
 	widget = gtk_label_new(plugin->Name);
 	gtk_widget_set_name(widget, "plugin_name");
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(upper_vbox), hbox, FALSE, FALSE, 2);
 
@@ -812,7 +812,7 @@ build_plugin_window(plugin_instance * instance) {
 		*c = '\0';
 	widget = gtk_label_new(maker);
 	gtk_widget_set_name(widget, "plugin_maker");
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(upper_vbox), hbox, FALSE, FALSE, 2);
 
@@ -844,11 +844,11 @@ build_plugin_window(plugin_instance * instance) {
 	arr_strlcat(str_inout, " ]");
  
 	widget = gtk_label_new(str_inout);
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(upper_vbox), hbox, FALSE, FALSE, 2);
 
-	upper_vbox = gtk_vbox_new(FALSE, 0);
+	upper_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_box_pack_end(GTK_BOX(upper_hbox), upper_vbox, FALSE, FALSE, 2);
 
 
@@ -898,7 +898,7 @@ build_plugin_window(plugin_instance * instance) {
 				       GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_box_pack_start(GTK_BOX(vbox), scrwin, TRUE, TRUE, 2);
 
-	inner_vbox = gtk_vbox_new(FALSE, 0);
+	inner_vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
 	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrwin), inner_vbox);
 
 	if ((n_toggled) || (n_untoggled) || (n_outctl) || (n_outlat)) {
@@ -918,7 +918,7 @@ build_plugin_window(plugin_instance * instance) {
 				continue;
 			
 			widget = gtk_label_new(plugin->PortNames[k]);
-			hbox = gtk_hbox_new(FALSE, 0);
+			hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 			gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 0);
 			gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, i, i+1,
 					 GTK_FILL, GTK_FILL | GTK_EXPAND, 2, 2);
@@ -951,7 +951,7 @@ build_plugin_window(plugin_instance * instance) {
 	}
 
 	if ((n_toggled) && (n_untoggled)) {
-		hseparator = gtk_hseparator_new();
+		hseparator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 		gtk_table_attach(GTK_TABLE(table), hseparator, 0, 3, i, i+1, GTK_FILL, GTK_FILL, 2, 2);
 		++i;
 		gtk_widget_size_request(hseparator, &req);
@@ -970,7 +970,7 @@ build_plugin_window(plugin_instance * instance) {
 				continue;
 			
 			widget = gtk_label_new(plugin->PortNames[k]);
-                        hbox = gtk_hbox_new(FALSE, 0);
+                        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
                         gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 0);
 			gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, i, i+1,
 					 GTK_FILL, GTK_FILL | GTK_EXPAND, 2, 2);
@@ -1064,13 +1064,14 @@ build_plugin_window(plugin_instance * instance) {
 			defs = lrdf_get_scale_values(plugin->UniqueID, k);
 			if ((defs) && (defs->count > 0)) { /* have scale values */
 
-                                combo = gtk_combo_box_new_text (); 
+                                combo = gtk_combo_box_text_new ();
 				gtk_widget_set_name(combo, "plugin_combo");
 				gtk_table_attach(GTK_TABLE(table), combo, 1, 3, i, i+1,
 						 GTK_FILL | GTK_EXPAND, GTK_FILL, 2, 2);
 
 				for (j = 0; j < defs->count; j++) {
-	                                gtk_combo_box_append_text (GTK_COMBO_BOX (combo), defs->items[j].label);
+	                                gtk_combo_box_text_append_text(
+                                           GTK_COMBO_BOX_TEXT (combo), defs->items[j].label);
 				}
 
 				gtk_widget_size_request(combo, &req);
@@ -1098,13 +1099,13 @@ build_plugin_window(plugin_instance * instance) {
 
 			} else { /* no scale values */
 
-				adjustment = gtk_adjustment_new(start, min, max, step, step * 50.0, 0.0);
+				adjustment = G_OBJECT(gtk_adjustment_new(start, min, max, step, step * 50.0, 0.0));
 				instance->adjustments[k] = GTK_ADJUSTMENT(adjustment);
 				g_signal_connect(G_OBJECT(adjustment), "value_changed",
 						 G_CALLBACK(plugin_value_changed), &(instance->knobs[k]));
 				
 				if (!LADSPA_IS_HINT_INTEGER(hints[k].HintDescriptor)) {
-					widget = gtk_hscale_new(GTK_ADJUSTMENT(adjustment));
+					widget = gtk_scale_new(GTK_ORIENTATION_HORIZONTAL, GTK_ADJUSTMENT(adjustment));
 					gtk_widget_set_name(widget, "plugin_scale");
 					gtk_widget_set_size_request(widget, 200, -1);
 					gtk_scale_set_digits(GTK_SCALE(widget), dp);
@@ -1146,7 +1147,7 @@ build_plugin_window(plugin_instance * instance) {
 
 
 	if (((n_toggled) || (n_untoggled)) && (n_outctl)) {
-		hseparator = gtk_hseparator_new();
+		hseparator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 		gtk_table_attach(GTK_TABLE(table), hseparator, 0, 3, i, i+1, GTK_FILL, GTK_FILL, 2, 2);
 		++i;
 		gtk_widget_size_request(hseparator, &req);
@@ -1165,7 +1166,7 @@ build_plugin_window(plugin_instance * instance) {
 				continue;
 			
 			widget = gtk_label_new(plugin->PortNames[k]);
-                        hbox = gtk_hbox_new(FALSE, 0);
+                        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
                         gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 0);
 			gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, i, i+1,
 					 GTK_FILL, GTK_FILL | GTK_EXPAND, 2, 2);
@@ -1253,11 +1254,11 @@ build_plugin_window(plugin_instance * instance) {
 			
 			instance->knobs[k] = start;
 			
-			adjustment = gtk_adjustment_new(start, min, max, step, step * 50.0, 0.0);
+			adjustment = G_OBJECT(gtk_adjustment_new(start, min, max, step, step * 50.0, 0.0));
 			instance->adjustments[k] = GTK_ADJUSTMENT(adjustment);
 			
 			if (!LADSPA_IS_HINT_INTEGER(hints[k].HintDescriptor)) {
-				widget = gtk_hscale_new(GTK_ADJUSTMENT(adjustment));
+				widget = gtk_scale_new(GTK_ORIENTATION_HORIZONTAL, GTK_ADJUSTMENT(adjustment));
 				gtk_widget_set_name(widget, "plugin_scale");
 				gtk_widget_set_size_request(widget, 200, -1);
 				gtk_scale_set_digits(GTK_SCALE(widget), dp);
@@ -1287,7 +1288,7 @@ build_plugin_window(plugin_instance * instance) {
 
 
 	if (((n_toggled) || (n_untoggled) || (n_outctl)) && (n_outlat)) {
-		hseparator = gtk_hseparator_new();
+		hseparator = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
 		gtk_table_attach(GTK_TABLE(table), hseparator, 0, 3, i, i+1, GTK_FILL, GTK_FILL, 2, 2);
 		++i;
 		gtk_widget_size_request(hseparator, &req);
@@ -1306,7 +1307,7 @@ build_plugin_window(plugin_instance * instance) {
 				continue;
 			
 			widget = gtk_label_new(plugin->PortNames[k]);
-                        hbox = gtk_hbox_new(FALSE, 0);
+                        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
                         gtk_box_pack_start(GTK_BOX(hbox), widget, FALSE, FALSE, 0);
 			gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, i, i+1,
 					 GTK_FILL, GTK_FILL | GTK_EXPAND, 2, 2);
@@ -1394,11 +1395,11 @@ build_plugin_window(plugin_instance * instance) {
 			
 			instance->knobs[k] = start;
 			
-			adjustment = gtk_adjustment_new(start, min, max, step, step * 50.0, 0.0);
+			adjustment = G_OBJECT(gtk_adjustment_new(start, min, max, step, step * 50.0, 0.0));
 			instance->adjustments[k] = GTK_ADJUSTMENT(adjustment);
 			
 			if (!LADSPA_IS_HINT_INTEGER(hints[k].HintDescriptor)) {
-				widget = gtk_hscale_new(GTK_ADJUSTMENT(adjustment));
+				widget = gtk_scale_new(GTK_ORIENTATION_HORIZONTAL, GTK_ADJUSTMENT(adjustment));
 				gtk_widget_set_name(widget, "plugin_scale");
 				gtk_widget_set_size_request(widget, 200, -1);
 				gtk_scale_set_digits(GTK_SCALE(widget), dp);
@@ -1586,8 +1587,8 @@ gint
 running_list_key_pressed(GtkWidget * widget, GdkEventKey * event) {
 
 	switch (event->keyval) {
-	case GDK_Delete:
-	case GDK_KP_Delete:
+	case GDK_KEY_Delete:
+	case GDK_KEY_KP_Delete:
 		remove_clicked(NULL, NULL, NULL);
 		return TRUE;
 		break;
@@ -1664,8 +1665,8 @@ gint
 avail_key_pressed(GtkWidget * widget, GdkEventKey * event) {
 
 	switch (event->keyval) {
-	case GDK_a:
-	case GDK_A:
+	case GDK_KEY_a:
+	case GDK_KEY_A:
 		add_clicked(NULL, NULL, NULL);
 		return TRUE;
 		break;
@@ -1806,13 +1807,13 @@ create_fxbuilder(void) {
         g_signal_connect(G_OBJECT(fxbuilder_window), "key_press_event", G_CALLBACK(fxbuilder_key_pressed), NULL);
         gtk_container_set_border_width(GTK_CONTAINER(fxbuilder_window), 2);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_container_add(GTK_CONTAINER(fxbuilder_window), hbox);
 
         frame_avail = gtk_frame_new(_("Available plugins"));
         gtk_box_pack_start(GTK_BOX(hbox), frame_avail, TRUE, TRUE, 5);
 
-	vbox = gtk_vbox_new(FALSE, 0);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(vbox), 3);
         gtk_container_add(GTK_CONTAINER(frame_avail), vbox);
 
@@ -1915,14 +1916,15 @@ create_fxbuilder(void) {
         frame_running = gtk_frame_new(_("Running plugins"));
         gtk_box_pack_start(GTK_BOX(hbox), frame_running, TRUE, TRUE, 5);
 
-	vbox = gtk_vbox_new(FALSE, 0);
+	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_set_border_width(GTK_CONTAINER(vbox), 3);
         gtk_container_add(GTK_CONTAINER(frame_running), vbox);
 
 	viewport_running = gtk_viewport_new(NULL, NULL);
         gtk_box_pack_start(GTK_BOX(vbox), viewport_running, TRUE, TRUE, 3);
 
-	hbox_buttons = gtk_hbox_new(TRUE, 0);
+	hbox_buttons = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+        gtk_widget_set_hexpand(hbox, TRUE);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox_buttons, FALSE, TRUE, 3);
 
         remove_button = gtk_button_new_from_stock (GTK_STOCK_REMOVE); 
