@@ -38,6 +38,7 @@
 #define LIST_WIDTH 200
 #define LIST_HEIGHT 100
 
+#define TVCOL_BUTTON(tvcol) gtk_tree_view_column_get_button(tvcol)
 
 extern GtkWidget * main_window;
 
@@ -168,8 +169,8 @@ void
 clicked_out_L_header(GtkWidget * widget, gpointer * data) {
 
 	out_selector = 0;
-	set_active(GTK_WIDGET(column_out_L->button), 1);
-	set_active(GTK_WIDGET(column_out_R->button), 0);
+	set_active(GTK_WIDGET(TVCOL_BUTTON(column_out_L)), 1);
+	set_active(GTK_WIDGET(TVCOL_BUTTON(column_out_R)), 0);
 }
 
 
@@ -177,13 +178,13 @@ void
 clicked_out_R_header(GtkWidget * widget, gpointer * data) {
 
 	out_selector = 1;
-	set_active(GTK_WIDGET(column_out_L->button), 0);
-	set_active(GTK_WIDGET(column_out_R->button), 1);
+	set_active(GTK_WIDGET(TVCOL_BUTTON(column_out_L)), 0);
+	set_active(GTK_WIDGET(TVCOL_BUTTON(column_out_R)), 1);
 }
 
 
 void
-tree_out_nb_selection_changed(GtkObject * tree, gpointer * data) {
+tree_out_nb_selection_changed(GObject * tree, gpointer * data) {
 
 	GtkTreeIter iter;
         GtkTreeModel * model;
@@ -208,8 +209,8 @@ tree_out_nb_selection_changed(GtkObject * tree, gpointer * data) {
 				gtk_list_store_clear(store_out_L);
 				scan_connections(out_L_port, store_out_L);
 				out_selector = 1;
-				set_active(GTK_WIDGET(column_out_L->button), 0);
-				set_active(GTK_WIDGET(column_out_R->button), 1);
+				set_active(GTK_WIDGET(TVCOL_BUTTON(column_out_L)), 0);
+				set_active(GTK_WIDGET(TVCOL_BUTTON(column_out_R)), 1);
 			}
 		} else {
 			if (jack_connect(jack_client, jack_port_name(out_R_port), fullname)) {
@@ -219,8 +220,8 @@ tree_out_nb_selection_changed(GtkObject * tree, gpointer * data) {
 				gtk_list_store_clear(store_out_R);
 				scan_connections(out_R_port, store_out_R);
 				out_selector = 0;
-				set_active(GTK_WIDGET(column_out_L->button), 1);
-				set_active(GTK_WIDGET(column_out_R->button), 0);
+				set_active(GTK_WIDGET(TVCOL_BUTTON(column_out_L)), 1);
+				set_active(GTK_WIDGET(TVCOL_BUTTON(column_out_R)), 0);
 			}
 		}
         }
@@ -454,7 +455,7 @@ port_setup_dialog(void) {
 	gtk_window_set_transient_for(GTK_WINDOW(ports_window), GTK_WINDOW(main_window));
         g_signal_connect(G_OBJECT(ports_window), "delete_event", G_CALLBACK(port_window_close), NULL);
 
-        vbox = gtk_vbox_new(FALSE, 0);
+        vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_add(GTK_CONTAINER(ports_window), vbox);
 
         table = gtk_table_new(2, 2, FALSE);
@@ -478,11 +479,11 @@ port_setup_dialog(void) {
         gtk_table_attach(GTK_TABLE(table), frame_dr, 1, 2, 0, 1,
                          GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND, 5, 5);
 
-        vbox_dl = gtk_vbox_new(FALSE, 5);
+        vbox_dl = gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox_dl), 8);
 	gtk_container_add(GTK_CONTAINER(frame_dl), vbox_dl);
 
-        vbox_dr = gtk_vbox_new(FALSE, 5);
+        vbox_dr = gtk_box_new(GTK_ORIENTATION_VERTICAL, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox_dr), 8);
 	gtk_container_add(GTK_CONTAINER(frame_dr), vbox_dr);
 
@@ -508,11 +509,11 @@ port_setup_dialog(void) {
 	gtk_tree_view_append_column(GTK_TREE_VIEW(tree_out_L), column_out_L);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(tree_out_R), column_out_R);
 
-	g_signal_connect(G_OBJECT(column_out_L->button), "clicked", G_CALLBACK(clicked_out_L_header), NULL);
-	g_signal_connect(G_OBJECT(column_out_R->button), "clicked", G_CALLBACK(clicked_out_R_header), NULL);
+	g_signal_connect(G_OBJECT(TVCOL_BUTTON(column_out_L)), "clicked", G_CALLBACK(clicked_out_L_header), NULL);
+	g_signal_connect(G_OBJECT(TVCOL_BUTTON(column_out_R)), "clicked", G_CALLBACK(clicked_out_R_header), NULL);
 	
-	gtk_widget_set_name(column_out_L->button, "nostyle");
-	gtk_widget_set_name(column_out_R->button, "nostyle");
+	gtk_widget_set_name(TVCOL_BUTTON(column_out_L), "nostyle");
+	gtk_widget_set_name(TVCOL_BUTTON(column_out_R), "nostyle");
 	
 	select_out_L = gtk_tree_view_get_selection(GTK_TREE_VIEW(tree_out_L));
 	gtk_tree_selection_set_mode(select_out_L, GTK_SELECTION_SINGLE);
@@ -540,22 +541,22 @@ port_setup_dialog(void) {
 
 	setup_notebook_out();
 
-	set_active(GTK_WIDGET(column_out_L->button), TRUE);
-	set_active(GTK_WIDGET(column_out_R->button), FALSE);
+	set_active(GTK_WIDGET(TVCOL_BUTTON(column_out_L)), TRUE);
+	set_active(GTK_WIDGET(TVCOL_BUTTON(column_out_R)), FALSE);
 
 	gtk_widget_show_all(ports_window);
 
-	gtk_widget_destroy(gtk_bin_get_child(GTK_BIN(column_out_L->button)));
-	gtk_widget_destroy(gtk_bin_get_child(GTK_BIN(column_out_R->button)));
+	gtk_widget_destroy(gtk_bin_get_child(GTK_BIN(TVCOL_BUTTON(column_out_L))));
+	gtk_widget_destroy(gtk_bin_get_child(GTK_BIN(TVCOL_BUTTON(column_out_R))));
 
-	hbox_L = gtk_hbox_new(FALSE, 0);
-	hbox_R = gtk_hbox_new(FALSE, 0);
+	hbox_L = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+	hbox_R = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 
 	label_L = gtk_label_new(_(" out L"));
 	label_R = gtk_label_new(_(" out R"));
 
-	gtk_container_add(GTK_CONTAINER(column_out_L->button), hbox_L);
-	gtk_container_add(GTK_CONTAINER(column_out_R->button), hbox_R);
+	gtk_container_add(GTK_CONTAINER(TVCOL_BUTTON(column_out_L)), hbox_L);
+	gtk_container_add(GTK_CONTAINER(TVCOL_BUTTON(column_out_R)), hbox_R);
 
 	gtk_box_pack_start(GTK_BOX(hbox_L), label_L, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox_R), label_R, FALSE, FALSE, 0);
@@ -574,4 +575,3 @@ port_setup_dialog(void) {
 
 
 // vim: shiftwidth=8:tabstop=8:softtabstop=8 :  
-
