@@ -45,6 +45,7 @@ extern GtkWidget * music_tree;
 extern GtkWidget * browser_window;
 
 GtkWidget * search_window = NULL;
+static int search_store_quit = 0;
 GtkWidget * searchkey_entry;
 
 GtkWidget * check_case;
@@ -114,6 +115,7 @@ close_button_clicked(GtkWidget * widget, gpointer data) {
                           (artist_yes * SEARCH_F_AN) | (record_yes * SEARCH_F_RT) | (track_yes * SEARCH_F_TT) |
                           (comment_yes * SEARCH_F_CO);
 
+	search_store_quit = 1;
 	clear_search_store();
         gtk_widget_destroy(search_window);
         search_window = NULL;
@@ -129,6 +131,7 @@ search_window_close(GtkWidget * widget, gpointer * data) {
                           (artist_yes * SEARCH_F_AN) | (record_yes * SEARCH_F_RT) | (track_yes * SEARCH_F_TT) |
                           (comment_yes * SEARCH_F_CO);
 
+	search_store_quit = 1;
 	clear_search_store();
         search_window = NULL;
         return 0;
@@ -223,7 +226,7 @@ search_button_clicked(GtkWidget * widget, gpointer data) {
 				} else {
 					tmp = g_utf8_strup(artist_name, -1);
 				}
-				if (g_pattern_match_string(pattern, tmp)) {
+				if (g_pattern_spec_match_string(pattern, tmp)) {
 
 					GtkTreeIter iter;
 					GtkTreePath * path;
@@ -248,7 +251,7 @@ search_button_clicked(GtkWidget * widget, gpointer data) {
 				} else {
 					tmp = g_utf8_strup(artist_data->comment, -1);
 				}
-				if (g_pattern_match_string(pattern, tmp)) {
+				if (g_pattern_spec_match_string(pattern, tmp)) {
 
 					GtkTreeIter iter;
 					GtkTreePath * path;
@@ -284,7 +287,7 @@ search_button_clicked(GtkWidget * widget, gpointer data) {
 					} else {
 						tmp = g_utf8_strup(record_name, -1);
 					}
-					if (g_pattern_match_string(pattern, tmp)) {
+					if (g_pattern_spec_match_string(pattern, tmp)) {
 						
 						GtkTreeIter iter;
 						GtkTreePath * path;
@@ -309,7 +312,7 @@ search_button_clicked(GtkWidget * widget, gpointer data) {
 					} else {
 						tmp = g_utf8_strup(record_data->comment, -1);
 					}
-					if (g_pattern_match_string(pattern, tmp)) {
+					if (g_pattern_spec_match_string(pattern, tmp)) {
 						
 						GtkTreeIter iter;
 						GtkTreePath * path;
@@ -345,7 +348,7 @@ search_button_clicked(GtkWidget * widget, gpointer data) {
 						} else {
 							tmp = g_utf8_strup(track_name, -1);
 						}
-						if (g_pattern_match_string(pattern, tmp)) {
+						if (g_pattern_spec_match_string(pattern, tmp)) {
 							
 							GtkTreeIter iter;
 							GtkTreePath * path;
@@ -370,7 +373,7 @@ search_button_clicked(GtkWidget * widget, gpointer data) {
 						} else {
 							tmp = g_utf8_strup(track_data->comment, -1);
 						}
-						if (g_pattern_match_string(pattern, tmp)) {
+						if (g_pattern_spec_match_string(pattern, tmp)) {
 							
 							GtkTreeIter iter;
 							GtkTreePath * path;
@@ -403,7 +406,7 @@ search_button_clicked(GtkWidget * widget, gpointer data) {
 			gtk_tree_selection_select_iter(search_select, &sfac_iter);
 		}
 		
-		close_button_clicked(NULL, NULL);            
+		close_button_clicked(NULL, NULL);
 	}
 
 	return TRUE;
@@ -417,6 +420,8 @@ search_selection_changed(GtkTreeSelection * treeselection, gpointer user_data) {
 	GtkTreePath * path;
 	gpointer gptr;
 
+	if (search_store_quit)
+		return;
 
 	if (!gtk_tree_selection_get_selected(search_select, NULL, &iter)) {
 		return;
@@ -438,13 +443,13 @@ search_window_key_pressed(GtkWidget * widget, GdkEventKey * kevent) {
 
 	switch (kevent->keyval) {
 
-	case GDK_Escape:
+	case GDK_KEY_Escape:
 		close_button_clicked(NULL, NULL);
 		return TRUE;
 		break;
 
-	case GDK_Return:
-	case GDK_KP_Enter:
+	case GDK_KEY_Return:
+	case GDK_KEY_KP_Enter:
 		search_button_clicked(NULL, NULL);
 		return TRUE;
 		break;
@@ -474,6 +479,7 @@ search_dialog(void) {
         if (search_window != NULL) {
 		return;
         }
+	search_store_quit = 0;
 
         search_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
         gtk_window_set_title(GTK_WINDOW(search_window), _("Search the Music Store"));
@@ -485,12 +491,12 @@ search_dialog(void) {
 			 G_CALLBACK(search_window_key_pressed), NULL);
         gtk_container_set_border_width(GTK_CONTAINER(search_window), 5);
 
-        vbox = gtk_vbox_new(FALSE, 0);
+        vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_widget_show(vbox);
         gtk_container_add(GTK_CONTAINER(search_window), vbox);
 
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_widget_show(hbox);
         gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 3);
 
@@ -526,7 +532,7 @@ search_dialog(void) {
 	gtk_table_attach(GTK_TABLE(table), check_sfac, 0, 1, 1, 2,
 			 GTK_EXPAND | GTK_FILL, GTK_FILL, 1, 5);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_widget_show(hbox);     
 	label = gtk_label_new(_("Search in:"));
         gtk_widget_show(label);     
@@ -559,7 +565,7 @@ search_dialog(void) {
 	gtk_table_attach(GTK_TABLE(table), check_comment, 1, 2, 4, 5,
 			 GTK_EXPAND | GTK_FILL, GTK_FILL, 1, 1);
 
-	hbox = sres_list = gtk_hbox_new(FALSE, 0);
+	hbox = sres_list = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_widget_show(hbox);     
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 3);
         gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 3);
@@ -625,7 +631,7 @@ search_dialog(void) {
         gtk_tree_view_column_set_sort_column_id(GTK_TREE_VIEW_COLUMN(search_column), 2);
         gtk_tree_view_append_column(GTK_TREE_VIEW(search_list), search_column);
 
-	hbuttonbox = gtk_hbutton_box_new();
+	hbuttonbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
         gtk_widget_show (hbuttonbox);
         gtk_box_set_spacing(GTK_BOX(hbuttonbox), 8);
 	gtk_box_pack_end(GTK_BOX(vbox), hbuttonbox, FALSE, TRUE, 0);
