@@ -49,6 +49,7 @@ extern GtkWidget * main_window;
 extern GList * playlists;
 
 static GtkWidget * search_window = NULL;
+static int search_playlist_quit = 0;
 static GtkWidget * searchkey_entry;
 
 static GtkWidget * check_case;
@@ -103,6 +104,7 @@ close_button_clicked(GtkWidget * widget, gpointer data) {
         get_toggle_buttons_state();
         options.search_pl_flags = (casesens * SEARCH_F_CS) | (exactonly * SEARCH_F_EM) | (selectfc * SEARCH_F_SF);
 
+	search_playlist_quit = 1;
 	clear_search_store();
         gtk_widget_destroy(search_window);
         search_window = NULL;
@@ -116,6 +118,7 @@ search_window_close(GtkWidget * widget, gpointer * data) {
         get_toggle_buttons_state();
         options.search_pl_flags = (casesens * SEARCH_F_CS) | (exactonly * SEARCH_F_EM) | (selectfc * SEARCH_F_SF);
 
+	search_playlist_quit = 1;
 	clear_search_store();
         search_window = NULL;
         return 0;
@@ -159,7 +162,7 @@ search_foreach(playlist_t * pl, GPatternSpec * pattern, GtkTreeIter * list_iter,
 		tmp = g_utf8_strup(text, -1);
 	}
 
-	if (g_pattern_match_string(pattern, tmp)) {
+	if (g_pattern_spec_match_string(pattern, tmp)) {
 
 		GtkTreeIter iter;
 		GtkTreePath * path;
@@ -264,6 +267,9 @@ search_selection_changed(GtkTreeSelection * treeselection, gpointer user_data) {
 	gpointer gptr2;
 	playlist_t * pl;
 
+	if (search_playlist_quit)
+		return;
+
 	if (!gtk_tree_selection_get_selected(search_select, NULL, &iter)) {
 		return;
 	}
@@ -294,13 +300,13 @@ search_window_key_pressed(GtkWidget * widget, GdkEventKey * kevent) {
 
 	switch (kevent->keyval) {
 
-	case GDK_Escape:
+	case GDK_KEY_Escape:
 		close_button_clicked(NULL, NULL);
 		return TRUE;
 		break;
 
-	case GDK_Return:
-	case GDK_KP_Enter:
+	case GDK_KEY_Return:
+	case GDK_KEY_KP_Enter:
 		search_button_clicked(NULL, NULL);
                 return TRUE;
 		break;
@@ -330,6 +336,7 @@ search_playlist_dialog(void) {
         if (search_window != NULL) {
 		return;
         }
+	search_playlist_quit = 0;
 
         search_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
         gtk_window_set_title(GTK_WINDOW(search_window), _("Search the Playlist"));
@@ -347,11 +354,11 @@ search_playlist_dialog(void) {
 			 G_CALLBACK(search_window_key_pressed), NULL);
         gtk_container_set_border_width(GTK_CONTAINER(search_window), 5);
 
-        vbox = gtk_vbox_new(FALSE, 0);
+        vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_widget_show(vbox);
         gtk_container_add(GTK_CONTAINER(search_window), vbox);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_widget_show(hbox);
         gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 3);
 
@@ -388,7 +395,7 @@ search_playlist_dialog(void) {
 			 GTK_EXPAND | GTK_FILL, GTK_FILL, 1, 4);
 
 
-	hbox = sres_list = gtk_hbox_new(FALSE, 0);
+	hbox = sres_list = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_widget_show(hbox);     
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 3);
         gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 3);
@@ -443,7 +450,7 @@ search_playlist_dialog(void) {
         gtk_tree_view_column_set_sort_column_id(GTK_TREE_VIEW_COLUMN(search_column), 0);
         gtk_tree_view_append_column(GTK_TREE_VIEW(search_list), search_column);
 
-	hbuttonbox = gtk_hbutton_box_new();
+	hbuttonbox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
         gtk_widget_show (hbuttonbox);
         gtk_box_set_spacing(GTK_BOX(hbuttonbox), 8);
 	gtk_box_pack_end(GTK_BOX(vbox), hbuttonbox, FALSE, TRUE, 0);
