@@ -255,7 +255,7 @@ gui_stock_label_button(gchar *label, const gchar *stock) {
         }
 
 	alignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-	hbox = gtk_hbox_new (FALSE, 2);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
 	gtk_container_add (GTK_CONTAINER (alignment), hbox);
 
 	image = gtk_image_new_from_stock (stock, GTK_ICON_SIZE_BUTTON);
@@ -499,8 +499,10 @@ assign_audio_fc_filters(GtkFileChooser * fc) {
         gtk_file_filter_set_name(filter, _("LAVC audio/video files"));
 	{
 		char * valid_ext_lavc[] = {
-			"aac", "ac3", "asf", "avi", "m4a", "mpeg", "mpg", "mp3", "ra",
-			"wav", "wma", "wv", NULL };
+			"aac", "ac3", "aiff", "ape", "asf", "au", "avi", "flac", "m4a",
+			"mpa", "mpc", "mpeg", "mpega", "mpg", "mpga", "mp1", "mp2",
+			"mp2a", "mp3", "mpa2", "ogg", "ra", "spx", "voc", "w64", "wav",
+			"wma", "wv", NULL };
 		build_filter_from_extensions(filter, filter_all, valid_ext_lavc);
 	}
         gtk_file_chooser_add_filter(fc, filter);
@@ -683,7 +685,7 @@ insert_label_entry(GtkWidget * table, char * ltext, GtkWidget ** entry, char * e
 	GtkWidget * hbox;
 
 	label = gtk_label_new(ltext);
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, y1, y2, GTK_FILL, GTK_FILL, 5, 5);
 
@@ -705,11 +707,11 @@ insert_label_entry_button(GtkWidget * table, char * ltext, GtkWidget ** entry, c
 	GtkWidget * hbox;
 
 	label = gtk_label_new(ltext);
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, y1, y2, GTK_FILL, GTK_FILL, 5, 5);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 1, 2, y1, y2,
 			 GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 5);
 
@@ -741,11 +743,11 @@ insert_label_progbar_button(GtkWidget * table, char * ltext, GtkWidget ** progba
 	GtkWidget * hbox;
 
 	label = gtk_label_new(ltext);
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, y1, y2, GTK_FILL, GTK_FILL, 5, 5);
 
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 1, 2, y1, y2,
 			 GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 5);
 
@@ -765,7 +767,7 @@ insert_label_spin(GtkWidget * table, char * ltext, GtkWidget ** spin, int spinva
 	GtkWidget * hbox;
 
 	label = gtk_label_new(ltext);
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_table_attach(GTK_TABLE(table), hbox, 0, 1, y1, y2, GTK_FILL, GTK_FILL, 5, 5);
 
