@@ -158,9 +158,13 @@ volume_finalize(gpointer data) {
 
 	volume_t * vol = (volume_t *)data;
 
+	GtkAllocation win_allocation;
+	gtk_widget_get_allocation(vol_window, &win_allocation);
+	GtkAllocation slot_allocation;
+	gtk_widget_get_allocation(vol->slot, &slot_allocation);
 	gtk_window_resize(GTK_WINDOW(vol_window),
-			  vol_window->allocation.width,
-			  vol_window->allocation.height - vol->slot->allocation.height);
+			  win_allocation.width,
+			  win_allocation.height - slot_allocation.height);
 
 	gtk_widget_destroy(vol->slot);
 	vol->slot = NULL;
@@ -333,7 +337,7 @@ create_volume_window() {
 
         gtk_container_set_border_width(GTK_CONTAINER(vol_window), 5);
 
-        vbox = gtk_vbox_new(FALSE, 0);
+        vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
         gtk_container_add(GTK_CONTAINER(vol_window), vbox);
 
         gtk_widget_show_all(vol_window);
@@ -357,10 +361,10 @@ vol_create_gui(volume_t * vol) {
 	vol->slot = gtk_table_new(4, 3, FALSE);
         gtk_box_pack_start(GTK_BOX(vbox), vol->slot, FALSE, FALSE, 0);
 
-	gtk_table_attach(GTK_TABLE(vol->slot), gtk_hseparator_new(), 0, 3, 0, 1,
+	gtk_table_attach(GTK_TABLE(vol->slot), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), 0, 3, 0, 1,
 			 GTK_FILL, GTK_FILL, 5, 5);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	label = gtk_label_new(_("File:"));
         gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_table_attach(GTK_TABLE(vol->slot), hbox, 0, 1, 1, 2,
@@ -376,7 +380,7 @@ vol_create_gui(volume_t * vol) {
 	gtk_table_attach(GTK_TABLE(vol->slot), vol->pause_button, 2, 3, 1, 2,
 			 GTK_FILL, GTK_FILL, 5, 5);
 
-        hbox = gtk_hbox_new(FALSE, 0);
+        hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
 	label = gtk_label_new(_("Progress:"));
         gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_table_attach(GTK_TABLE(vol->slot), hbox, 0, 1, 2, 3,
@@ -393,7 +397,7 @@ vol_create_gui(volume_t * vol) {
 	gtk_table_attach(GTK_TABLE(vol->slot), vol->cancel_button, 2, 3, 2, 3,
 			 GTK_FILL, GTK_FILL, 5, 5);
 
-	gtk_table_attach(GTK_TABLE(vol->slot), gtk_hseparator_new(), 0, 3, 3, 4,
+	gtk_table_attach(GTK_TABLE(vol->slot), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), 0, 3, 3, 4,
 			 GTK_FILL, GTK_FILL, 5, 5);
 
 	gtk_widget_show_all(vol->slot);
